# -*- coding: utf-8 -*-

################################################################################
## Form generated from reading UI file 'u2dplot.ui'
##
## Created by: Qt User Interface Compiler version 5.15.2
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide2.QtCore import *
from PySide2.QtGui import *
from PySide2.QtWidgets import *


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        if not MainWindow.objectName():
            MainWindow.setObjectName(u"MainWindow")
        MainWindow.resize(800, 800)
        font = QFont()
        font.setPointSize(12)
        MainWindow.setFont(font)
        icon = QIcon()
        icon.addFile(u":/ugao_icon.png", QSize(), QIcon.Normal, QIcon.Off)
        MainWindow.setWindowIcon(icon)
        self.actionOpen = QAction(MainWindow)
        self.actionOpen.setObjectName(u"actionOpen")
        self.actionSave_as_Binary = QAction(MainWindow)
        self.actionSave_as_Binary.setObjectName(u"actionSave_as_Binary")
        self.actionSave_as_Text = QAction(MainWindow)
        self.actionSave_as_Text.setObjectName(u"actionSave_as_Text")
        self.actionExit = QAction(MainWindow)
        self.actionExit.setObjectName(u"actionExit")
        self.actionSet_View_Parameters = QAction(MainWindow)
        self.actionSet_View_Parameters.setObjectName(u"actionSet_View_Parameters")
        self.actionSet_Regions = QAction(MainWindow)
        self.actionSet_Regions.setObjectName(u"actionSet_Regions")
        self.actionSet_Regions.setEnabled(True)
        self.actionOpen_View_Parameters = QAction(MainWindow)
        self.actionOpen_View_Parameters.setObjectName(u"actionOpen_View_Parameters")
        self.actionSave_View_Parameters = QAction(MainWindow)
        self.actionSave_View_Parameters.setObjectName(u"actionSave_View_Parameters")
        self.actionShow_All_Regions = QAction(MainWindow)
        self.actionShow_All_Regions.setObjectName(u"actionShow_All_Regions")
        self.actionHide_All_Regions = QAction(MainWindow)
        self.actionHide_All_Regions.setObjectName(u"actionHide_All_Regions")
        self.actionSlice_setting = QAction(MainWindow)
        self.actionSlice_setting.setObjectName(u"actionSlice_setting")
        self.centralwidget = QWidget(MainWindow)
        self.centralwidget.setObjectName(u"centralwidget")
        self.verticalLayout = QVBoxLayout(self.centralwidget)
        self.verticalLayout.setObjectName(u"verticalLayout")
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QMenuBar(MainWindow)
        self.menubar.setObjectName(u"menubar")
        self.menubar.setGeometry(QRect(0, 0, 800, 21))
        font1 = QFont()
        font1.setFamily(u"MS UI Gothic")
        font1.setBold(True)
        font1.setWeight(75)
        self.menubar.setFont(font1)
        self.menubar.setDefaultUp(False)
        self.menuFile = QMenu(self.menubar)
        self.menuFile.setObjectName(u"menuFile")
        self.menuEdit = QMenu(self.menubar)
        self.menuEdit.setObjectName(u"menuEdit")
        self.menuView = QMenu(self.menubar)
        self.menuView.setObjectName(u"menuView")
        self.menuAnalyze = QMenu(self.menubar)
        self.menuAnalyze.setObjectName(u"menuAnalyze")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QStatusBar(MainWindow)
        self.statusbar.setObjectName(u"statusbar")
        self.statusbar.setFont(font1)
        MainWindow.setStatusBar(self.statusbar)

        self.menubar.addAction(self.menuFile.menuAction())
        self.menubar.addAction(self.menuEdit.menuAction())
        self.menubar.addAction(self.menuView.menuAction())
        self.menubar.addAction(self.menuAnalyze.menuAction())
        self.menuFile.addAction(self.actionOpen)
        self.menuFile.addAction(self.actionSave_as_Binary)
        self.menuFile.addAction(self.actionSave_as_Text)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionExit)
        self.menuEdit.addAction(self.actionSet_View_Parameters)
        self.menuEdit.addAction(self.actionSet_Regions)
        self.menuEdit.addAction(self.actionSlice_setting)
        self.menuEdit.addSeparator()
        self.menuEdit.addAction(self.actionOpen_View_Parameters)
        self.menuEdit.addAction(self.actionSave_View_Parameters)
        self.menuView.addAction(self.actionShow_All_Regions)
        self.menuView.addAction(self.actionHide_All_Regions)

        self.retranslateUi(MainWindow)

        QMetaObject.connectSlotsByName(MainWindow)
    # setupUi

    def retranslateUi(self, MainWindow):
        MainWindow.setWindowTitle(QCoreApplication.translate("MainWindow", u"MainWindow", None))
        self.actionOpen.setText(QCoreApplication.translate("MainWindow", u"Open", None))
#if QT_CONFIG(shortcut)
        self.actionOpen.setShortcut(QCoreApplication.translate("MainWindow", u"Ctrl+O", None))
#endif // QT_CONFIG(shortcut)
        self.actionSave_as_Binary.setText(QCoreApplication.translate("MainWindow", u"Save as Binary", None))
        self.actionSave_as_Text.setText(QCoreApplication.translate("MainWindow", u"Save as Text", None))
        self.actionExit.setText(QCoreApplication.translate("MainWindow", u"Exit", None))
        self.actionSet_View_Parameters.setText(QCoreApplication.translate("MainWindow", u"Set View Parameters", None))
#if QT_CONFIG(shortcut)
        self.actionSet_View_Parameters.setShortcut(QCoreApplication.translate("MainWindow", u"Ctrl+Shift+V", None))
#endif // QT_CONFIG(shortcut)
        self.actionSet_Regions.setText(QCoreApplication.translate("MainWindow", u"Set Regions", None))
#if QT_CONFIG(shortcut)
        self.actionSet_Regions.setShortcut(QCoreApplication.translate("MainWindow", u"Ctrl+Shift+R", None))
#endif // QT_CONFIG(shortcut)
        self.actionOpen_View_Parameters.setText(QCoreApplication.translate("MainWindow", u"Open View Parameters", None))
        self.actionSave_View_Parameters.setText(QCoreApplication.translate("MainWindow", u"Save View Parameters", None))
        self.actionShow_All_Regions.setText(QCoreApplication.translate("MainWindow", u"Show All Regions", None))
        self.actionHide_All_Regions.setText(QCoreApplication.translate("MainWindow", u"Hide All Regions", None))
        self.actionSlice_setting.setText(QCoreApplication.translate("MainWindow", u"Set Slice Regions", None))
        self.menuFile.setTitle(QCoreApplication.translate("MainWindow", u"File", None))
        self.menuEdit.setTitle(QCoreApplication.translate("MainWindow", u"Edit", None))
        self.menuView.setTitle(QCoreApplication.translate("MainWindow", u"View", None))
        self.menuAnalyze.setTitle(QCoreApplication.translate("MainWindow", u"Analyze", None))
    # retranslateUi

try:
    import u2dplot_rc
except:
    import uGao.u2dplot_rc

################################################################################
## Form generated from reading UI file 'dg_overplot.ui'
##
## Created by: Qt User Interface Compiler version 5.15.2
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide2.QtCore import *
from PySide2.QtGui import *
from PySide2.QtWidgets import *


class Ui_DgOverPlot(object):
    def setupUi(self, DgOverPlot):
        if not DgOverPlot.objectName():
            DgOverPlot.setObjectName(u"DgOverPlot")
        DgOverPlot.resize(592, 320)
        self.btAdd = QPushButton(DgOverPlot)
        self.btAdd.setObjectName(u"btAdd")
        self.btAdd.setGeometry(QRect(500, 20, 81, 27))
        self.btRemove = QPushButton(DgOverPlot)
        self.btRemove.setObjectName(u"btRemove")
        self.btRemove.setGeometry(QRect(500, 70, 81, 27))
        self.btClose = QPushButton(DgOverPlot)
        self.btClose.setObjectName(u"btClose")
        self.btClose.setGeometry(QRect(500, 290, 81, 27))

        self.retranslateUi(DgOverPlot)

        QMetaObject.connectSlotsByName(DgOverPlot)
    # setupUi

    def retranslateUi(self, DgOverPlot):
        DgOverPlot.setWindowTitle(QCoreApplication.translate("DgOverPlot", u"Dialog", None))
        self.btAdd.setText(QCoreApplication.translate("DgOverPlot", u"Add File ...", None))
        self.btRemove.setText(QCoreApplication.translate("DgOverPlot", u"Remove", None))
        self.btClose.setText(QCoreApplication.translate("DgOverPlot", u"Close", None))
    # retranslateUi


################################################################################
## Form generated from reading UI file 'dg_region.ui'
##
## Created by: Qt User Interface Compiler version 5.15.2
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide2.QtCore import *
from PySide2.QtGui import *
from PySide2.QtWidgets import *


class Ui_DlgRegion(object):
    def setupUi(self, DlgRegion):
        if not DlgRegion.objectName():
            DlgRegion.setObjectName(u"DlgRegion")
        DlgRegion.resize(600, 673)
        icon = QIcon()
        icon.addFile(u":/ugao_icon.png", QSize(), QIcon.Normal, QIcon.Off)
        DlgRegion.setWindowIcon(icon)
        self.tabRegion = QTabWidget(DlgRegion)
        self.tabRegion.setObjectName(u"tabRegion")
        self.tabRegion.setGeometry(QRect(10, 10, 501, 145))
        self.tabRegion.setTabPosition(QTabWidget.North)
        self.tabRegion.setTabShape(QTabWidget.Rounded)
        self.tabRegion.setIconSize(QSize(16, 16))
        self.tabRegion.setElideMode(Qt.ElideNone)
        self.tabRegion.setUsesScrollButtons(False)
        self.tabRegion.setDocumentMode(False)
        self.tabRegion.setTabsClosable(False)
        self.tabRegion.setMovable(False)
        self.tabPoint = QWidget()
        self.tabPoint.setObjectName(u"tabPoint")
        self.gridLayout_7 = QGridLayout(self.tabPoint)
        self.gridLayout_7.setObjectName(u"gridLayout_7")
        self.horizontalSpacer_17 = QSpacerItem(26, 20, QSizePolicy.Fixed, QSizePolicy.Minimum)

        self.gridLayout_7.addItem(self.horizontalSpacer_17, 0, 1, 1, 1)

        self.rs_label0_10 = QLabel(self.tabPoint)
        self.rs_label0_10.setObjectName(u"rs_label0_10")
        self.rs_label0_10.setMinimumSize(QSize(40, 0))

        self.gridLayout_7.addWidget(self.rs_label0_10, 0, 2, 1, 1)

        self.point_tx0 = QLineEdit(self.tabPoint)
        self.point_tx0.setObjectName(u"point_tx0")

        self.gridLayout_7.addWidget(self.point_tx0, 0, 3, 1, 1)

        self.point_label0_18 = QLabel(self.tabPoint)
        self.point_label0_18.setObjectName(u"point_label0_18")

        self.gridLayout_7.addWidget(self.point_label0_18, 0, 4, 1, 1)

        self.point_tx1 = QLineEdit(self.tabPoint)
        self.point_tx1.setObjectName(u"point_tx1")

        self.gridLayout_7.addWidget(self.point_tx1, 0, 5, 1, 1)

        self.horizontalSpacer_16 = QSpacerItem(48, 20, QSizePolicy.Fixed, QSizePolicy.Minimum)

        self.gridLayout_7.addItem(self.horizontalSpacer_16, 1, 0, 1, 1)

        self.horizontalSpacer_18 = QSpacerItem(26, 20, QSizePolicy.Fixed, QSizePolicy.Minimum)

        self.gridLayout_7.addItem(self.horizontalSpacer_18, 2, 1, 1, 1)

        self.tabRegion.addTab(self.tabPoint, "")
        self.tabLine = QWidget()
        self.tabLine.setObjectName(u"tabLine")
        self.gridLayout_5 = QGridLayout(self.tabLine)
        self.gridLayout_5.setObjectName(u"gridLayout_5")
        self.horizontalSpacer_8 = QSpacerItem(26, 20, QSizePolicy.Fixed, QSizePolicy.Minimum)

        self.gridLayout_5.addItem(self.horizontalSpacer_8, 0, 1, 1, 1)

        self.rs_label0_5 = QLabel(self.tabLine)
        self.rs_label0_5.setObjectName(u"rs_label0_5")

        self.gridLayout_5.addWidget(self.rs_label0_5, 0, 2, 1, 1)

        self.line_tx0 = QLineEdit(self.tabLine)
        self.line_tx0.setObjectName(u"line_tx0")

        self.gridLayout_5.addWidget(self.line_tx0, 0, 3, 1, 1)

        self.point_label0_14 = QLabel(self.tabLine)
        self.point_label0_14.setObjectName(u"point_label0_14")

        self.gridLayout_5.addWidget(self.point_label0_14, 0, 4, 1, 1)

        self.line_tx1 = QLineEdit(self.tabLine)
        self.line_tx1.setObjectName(u"line_tx1")

        self.gridLayout_5.addWidget(self.line_tx1, 0, 5, 1, 1)

        self.line_tx2 = QLineEdit(self.tabLine)
        self.line_tx2.setObjectName(u"line_tx2")

        self.gridLayout_5.addWidget(self.line_tx2, 1, 3, 1, 1)

        self.line_tx3 = QLineEdit(self.tabLine)
        self.line_tx3.setObjectName(u"line_tx3")

        self.gridLayout_5.addWidget(self.line_tx3, 1, 5, 1, 1)

        self.horizontalSpacer_9 = QSpacerItem(26, 20, QSizePolicy.Fixed, QSizePolicy.Minimum)

        self.gridLayout_5.addItem(self.horizontalSpacer_9, 2, 1, 1, 1)

        self.line_tx4 = QLineEdit(self.tabLine)
        self.line_tx4.setObjectName(u"line_tx4")

        self.gridLayout_5.addWidget(self.line_tx4, 2, 3, 1, 1)

        self.horizontalSpacer_10 = QSpacerItem(48, 20, QSizePolicy.Fixed, QSizePolicy.Minimum)

        self.gridLayout_5.addItem(self.horizontalSpacer_10, 1, 0, 1, 1)

        self.rs_label0_6 = QLabel(self.tabLine)
        self.rs_label0_6.setObjectName(u"rs_label0_6")

        self.gridLayout_5.addWidget(self.rs_label0_6, 1, 2, 1, 1)

        self.point_label0_16 = QLabel(self.tabLine)
        self.point_label0_16.setObjectName(u"point_label0_16")

        self.gridLayout_5.addWidget(self.point_label0_16, 1, 4, 1, 1)

        self.label_15 = QLabel(self.tabLine)
        self.label_15.setObjectName(u"label_15")
        self.label_15.setMinimumSize(QSize(40, 0))

        self.gridLayout_5.addWidget(self.label_15, 2, 2, 1, 1)

        self.tabRegion.addTab(self.tabLine, "")
        self.tabRectangle = QWidget()
        self.tabRectangle.setObjectName(u"tabRectangle")
        self.gridLayout_6 = QGridLayout(self.tabRectangle)
        self.gridLayout_6.setObjectName(u"gridLayout_6")
        self.horizontalSpacer_15 = QSpacerItem(26, 20, QSizePolicy.Fixed, QSizePolicy.Minimum)

        self.gridLayout_6.addItem(self.horizontalSpacer_15, 0, 1, 1, 1)

        self.rs_label0_8 = QLabel(self.tabRectangle)
        self.rs_label0_8.setObjectName(u"rs_label0_8")
        self.rs_label0_8.setMinimumSize(QSize(40, 0))

        self.gridLayout_6.addWidget(self.rs_label0_8, 0, 2, 1, 1)

        self.rect_tx0 = QLineEdit(self.tabRectangle)
        self.rect_tx0.setObjectName(u"rect_tx0")

        self.gridLayout_6.addWidget(self.rect_tx0, 0, 3, 1, 1)

        self.point_label0_15 = QLabel(self.tabRectangle)
        self.point_label0_15.setObjectName(u"point_label0_15")

        self.gridLayout_6.addWidget(self.point_label0_15, 0, 4, 1, 1)

        self.rect_tx1 = QLineEdit(self.tabRectangle)
        self.rect_tx1.setObjectName(u"rect_tx1")

        self.gridLayout_6.addWidget(self.rect_tx1, 0, 5, 1, 1)

        self.horizontalSpacer_14 = QSpacerItem(48, 20, QSizePolicy.Fixed, QSizePolicy.Minimum)

        self.gridLayout_6.addItem(self.horizontalSpacer_14, 1, 0, 1, 1)

        self.rs_label0_7 = QLabel(self.tabRectangle)
        self.rs_label0_7.setObjectName(u"rs_label0_7")

        self.gridLayout_6.addWidget(self.rs_label0_7, 1, 2, 1, 1)

        self.rect_tx2 = QLineEdit(self.tabRectangle)
        self.rect_tx2.setObjectName(u"rect_tx2")

        self.gridLayout_6.addWidget(self.rect_tx2, 1, 3, 1, 1)

        self.point_label0_17 = QLabel(self.tabRectangle)
        self.point_label0_17.setObjectName(u"point_label0_17")

        self.gridLayout_6.addWidget(self.point_label0_17, 1, 4, 1, 1)

        self.rect_tx3 = QLineEdit(self.tabRectangle)
        self.rect_tx3.setObjectName(u"rect_tx3")

        self.gridLayout_6.addWidget(self.rect_tx3, 1, 5, 1, 1)

        self.horizontalSpacer_13 = QSpacerItem(26, 20, QSizePolicy.Fixed, QSizePolicy.Minimum)

        self.gridLayout_6.addItem(self.horizontalSpacer_13, 2, 1, 1, 1)

        self.tabRegion.addTab(self.tabRectangle, "")
        self.tabCircle = QWidget()
        self.tabCircle.setObjectName(u"tabCircle")
        self.gridLayout_4 = QGridLayout(self.tabCircle)
        self.gridLayout_4.setObjectName(u"gridLayout_4")
        self.label_11 = QLabel(self.tabCircle)
        self.label_11.setObjectName(u"label_11")

        self.gridLayout_4.addWidget(self.label_11, 0, 0, 1, 1)

        self.horizontalSpacer_6 = QSpacerItem(47, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)

        self.gridLayout_4.addItem(self.horizontalSpacer_6, 0, 1, 1, 1)

        self.rs_label0_4 = QLabel(self.tabCircle)
        self.rs_label0_4.setObjectName(u"rs_label0_4")
        self.rs_label0_4.setMinimumSize(QSize(38, 0))

        self.gridLayout_4.addWidget(self.rs_label0_4, 0, 2, 1, 1)

        self.circle_tx0 = QLineEdit(self.tabCircle)
        self.circle_tx0.setObjectName(u"circle_tx0")

        self.gridLayout_4.addWidget(self.circle_tx0, 0, 3, 1, 1)

        self.point_label0_12 = QLabel(self.tabCircle)
        self.point_label0_12.setObjectName(u"point_label0_12")

        self.gridLayout_4.addWidget(self.point_label0_12, 0, 4, 1, 1)

        self.circle_tx1 = QLineEdit(self.tabCircle)
        self.circle_tx1.setObjectName(u"circle_tx1")

        self.gridLayout_4.addWidget(self.circle_tx1, 0, 5, 1, 1)

        self.label_10 = QLabel(self.tabCircle)
        self.label_10.setObjectName(u"label_10")

        self.gridLayout_4.addWidget(self.label_10, 1, 0, 1, 1)

        self.circle_tx2 = QLineEdit(self.tabCircle)
        self.circle_tx2.setObjectName(u"circle_tx2")

        self.gridLayout_4.addWidget(self.circle_tx2, 1, 3, 1, 1)

        self.horizontalSpacer_5 = QSpacerItem(47, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)

        self.gridLayout_4.addItem(self.horizontalSpacer_5, 2, 1, 1, 1)

        self.horizontalSpacer_11 = QSpacerItem(48, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)

        self.gridLayout_4.addItem(self.horizontalSpacer_11, 2, 0, 1, 1)

        self.tabRegion.addTab(self.tabCircle, "")
        self.tabRing = QWidget()
        self.tabRing.setObjectName(u"tabRing")
        self.gridLayout_3 = QGridLayout(self.tabRing)
        self.gridLayout_3.setObjectName(u"gridLayout_3")
        self.label_9 = QLabel(self.tabRing)
        self.label_9.setObjectName(u"label_9")

        self.gridLayout_3.addWidget(self.label_9, 0, 0, 1, 1)

        self.ring_tx2 = QLineEdit(self.tabRing)
        self.ring_tx2.setObjectName(u"ring_tx2")

        self.gridLayout_3.addWidget(self.ring_tx2, 1, 3, 1, 1)

        self.point_label0_13 = QLabel(self.tabRing)
        self.point_label0_13.setObjectName(u"point_label0_13")
        self.point_label0_13.setTextFormat(Qt.AutoText)

        self.gridLayout_3.addWidget(self.point_label0_13, 1, 4, 1, 1)

        self.ring_tx3 = QLineEdit(self.tabRing)
        self.ring_tx3.setObjectName(u"ring_tx3")

        self.gridLayout_3.addWidget(self.ring_tx3, 1, 5, 1, 1)

        self.rs_label0_3 = QLabel(self.tabRing)
        self.rs_label0_3.setObjectName(u"rs_label0_3")
        self.rs_label0_3.setMinimumSize(QSize(38, 0))

        self.gridLayout_3.addWidget(self.rs_label0_3, 0, 2, 1, 1)

        self.ring_tx1 = QLineEdit(self.tabRing)
        self.ring_tx1.setObjectName(u"ring_tx1")

        self.gridLayout_3.addWidget(self.ring_tx1, 0, 5, 1, 1)

        self.ring_tx0 = QLineEdit(self.tabRing)
        self.ring_tx0.setObjectName(u"ring_tx0")

        self.gridLayout_3.addWidget(self.ring_tx0, 0, 3, 1, 1)

        self.point_label0_11 = QLabel(self.tabRing)
        self.point_label0_11.setObjectName(u"point_label0_11")
        self.point_label0_11.setMinimumSize(QSize(38, 0))

        self.gridLayout_3.addWidget(self.point_label0_11, 0, 4, 1, 1)

        self.horizontalSpacer_3 = QSpacerItem(32, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)

        self.gridLayout_3.addItem(self.horizontalSpacer_3, 0, 1, 1, 1)

        self.label_8 = QLabel(self.tabRing)
        self.label_8.setObjectName(u"label_8")

        self.gridLayout_3.addWidget(self.label_8, 1, 0, 1, 1)

        self.horizontalSpacer_4 = QSpacerItem(32, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)

        self.gridLayout_3.addItem(self.horizontalSpacer_4, 2, 1, 1, 1)

        self.horizontalSpacer_12 = QSpacerItem(48, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)

        self.gridLayout_3.addItem(self.horizontalSpacer_12, 2, 0, 1, 1)

        self.tabRegion.addTab(self.tabRing, "")
        self.tabSector = QWidget()
        self.tabSector.setObjectName(u"tabSector")
        self.gridLayout_2 = QGridLayout(self.tabSector)
        self.gridLayout_2.setObjectName(u"gridLayout_2")
        self.label_6 = QLabel(self.tabSector)
        self.label_6.setObjectName(u"label_6")
        self.label_6.setMinimumSize(QSize(48, 0))

        self.gridLayout_2.addWidget(self.label_6, 0, 0, 1, 1)

        self.horizontalSpacer_2 = QSpacerItem(32, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)

        self.gridLayout_2.addItem(self.horizontalSpacer_2, 0, 1, 1, 1)

        self.rs_label0_2 = QLabel(self.tabSector)
        self.rs_label0_2.setObjectName(u"rs_label0_2")
        self.rs_label0_2.setMinimumSize(QSize(38, 0))

        self.gridLayout_2.addWidget(self.rs_label0_2, 0, 2, 1, 1)

        self.sector_tx0 = QLineEdit(self.tabSector)
        self.sector_tx0.setObjectName(u"sector_tx0")

        self.gridLayout_2.addWidget(self.sector_tx0, 0, 3, 1, 1)

        self.point_label0_7 = QLabel(self.tabSector)
        self.point_label0_7.setObjectName(u"point_label0_7")
        self.point_label0_7.setMinimumSize(QSize(38, 0))

        self.gridLayout_2.addWidget(self.point_label0_7, 0, 4, 1, 1)

        self.sector_tx1 = QLineEdit(self.tabSector)
        self.sector_tx1.setObjectName(u"sector_tx1")

        self.gridLayout_2.addWidget(self.sector_tx1, 0, 5, 1, 1)

        self.label_5 = QLabel(self.tabSector)
        self.label_5.setObjectName(u"label_5")

        self.gridLayout_2.addWidget(self.label_5, 1, 0, 1, 1)

        self.sector_tx2 = QLineEdit(self.tabSector)
        self.sector_tx2.setObjectName(u"sector_tx2")

        self.gridLayout_2.addWidget(self.sector_tx2, 1, 3, 1, 1)

        self.label_7 = QLabel(self.tabSector)
        self.label_7.setObjectName(u"label_7")

        self.gridLayout_2.addWidget(self.label_7, 2, 0, 1, 1)

        self.sector_tx4 = QLineEdit(self.tabSector)
        self.sector_tx4.setObjectName(u"sector_tx4")

        self.gridLayout_2.addWidget(self.sector_tx4, 2, 3, 1, 1)

        self.point_label0_10 = QLabel(self.tabSector)
        self.point_label0_10.setObjectName(u"point_label0_10")
        self.point_label0_10.setTextFormat(Qt.AutoText)

        self.gridLayout_2.addWidget(self.point_label0_10, 2, 4, 1, 1)

        self.sector_tx5 = QLineEdit(self.tabSector)
        self.sector_tx5.setObjectName(u"sector_tx5")

        self.gridLayout_2.addWidget(self.sector_tx5, 2, 5, 1, 1)

        self.tabRegion.addTab(self.tabSector, "")
        self.tabRingSector = QWidget()
        self.tabRingSector.setObjectName(u"tabRingSector")
        self.gridLayout = QGridLayout(self.tabRingSector)
        self.gridLayout.setObjectName(u"gridLayout")
        self.gridLayout.setSizeConstraint(QLayout.SetNoConstraint)
        self.point_label0_8 = QLabel(self.tabRingSector)
        self.point_label0_8.setObjectName(u"point_label0_8")
        self.point_label0_8.setTextFormat(Qt.AutoText)

        self.gridLayout.addWidget(self.point_label0_8, 2, 4, 1, 1)

        self.label_3 = QLabel(self.tabRingSector)
        self.label_3.setObjectName(u"label_3")

        self.gridLayout.addWidget(self.label_3, 1, 0, 1, 1)

        self.rs_tx5 = QLineEdit(self.tabRingSector)
        self.rs_tx5.setObjectName(u"rs_tx5")

        self.gridLayout.addWidget(self.rs_tx5, 2, 5, 1, 1)

        self.rs_tx1 = QLineEdit(self.tabRingSector)
        self.rs_tx1.setObjectName(u"rs_tx1")

        self.gridLayout.addWidget(self.rs_tx1, 0, 5, 1, 1)

        self.rs_tx3 = QLineEdit(self.tabRingSector)
        self.rs_tx3.setObjectName(u"rs_tx3")

        self.gridLayout.addWidget(self.rs_tx3, 1, 5, 1, 1)

        self.rs_label0 = QLabel(self.tabRingSector)
        self.rs_label0.setObjectName(u"rs_label0")
        self.rs_label0.setMinimumSize(QSize(38, 0))

        self.gridLayout.addWidget(self.rs_label0, 0, 2, 1, 1)

        self.point_label0_9 = QLabel(self.tabRingSector)
        self.point_label0_9.setObjectName(u"point_label0_9")
        self.point_label0_9.setTextFormat(Qt.AutoText)

        self.gridLayout.addWidget(self.point_label0_9, 1, 4, 1, 1)

        self.label_4 = QLabel(self.tabRingSector)
        self.label_4.setObjectName(u"label_4")

        self.gridLayout.addWidget(self.label_4, 2, 0, 1, 1)

        self.rs_tx0 = QLineEdit(self.tabRingSector)
        self.rs_tx0.setObjectName(u"rs_tx0")

        self.gridLayout.addWidget(self.rs_tx0, 0, 3, 1, 1)

        self.point_label0_6 = QLabel(self.tabRingSector)
        self.point_label0_6.setObjectName(u"point_label0_6")
        self.point_label0_6.setMinimumSize(QSize(38, 0))

        self.gridLayout.addWidget(self.point_label0_6, 0, 4, 1, 1)

        self.rs_tx4 = QLineEdit(self.tabRingSector)
        self.rs_tx4.setObjectName(u"rs_tx4")

        self.gridLayout.addWidget(self.rs_tx4, 2, 3, 1, 1)

        self.rs_tx2 = QLineEdit(self.tabRingSector)
        self.rs_tx2.setObjectName(u"rs_tx2")

        self.gridLayout.addWidget(self.rs_tx2, 1, 3, 1, 1)

        self.horizontalSpacer = QSpacerItem(27, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)

        self.gridLayout.addItem(self.horizontalSpacer, 0, 1, 1, 1)

        self.label_2 = QLabel(self.tabRingSector)
        self.label_2.setObjectName(u"label_2")
        self.label_2.setMinimumSize(QSize(48, 0))

        self.gridLayout.addWidget(self.label_2, 0, 0, 1, 1)

        self.horizontalSpacer_7 = QSpacerItem(20, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)

        self.gridLayout.addItem(self.horizontalSpacer_7, 2, 1, 1, 1)

        self.tabRegion.addTab(self.tabRingSector, "")
        self.frame = QFrame(DlgRegion)
        self.frame.setObjectName(u"frame")
        self.frame.setGeometry(QRect(280, 220, 241, 341))
        self.frame.setFrameShape(QFrame.StyledPanel)
        self.frame.setFrameShadow(QFrame.Raised)
        self.layoutWidget = QWidget(self.frame)
        self.layoutWidget.setObjectName(u"layoutWidget")
        self.layoutWidget.setGeometry(QRect(10, 10, 221, 229))
        self.vLayout_group = QVBoxLayout(self.layoutWidget)
        self.vLayout_group.setObjectName(u"vLayout_group")
        self.vLayout_group.setContentsMargins(0, 0, 0, 0)
        self.hLayout_group = QHBoxLayout()
        self.hLayout_group.setObjectName(u"hLayout_group")
        self.btnAddGrp = QPushButton(self.layoutWidget)
        self.btnAddGrp.setObjectName(u"btnAddGrp")
        self.btnAddGrp.setEnabled(True)
        self.btnAddGrp.setAutoDefault(False)

        self.hLayout_group.addWidget(self.btnAddGrp)

        self.btnDeleteGrp = QPushButton(self.layoutWidget)
        self.btnDeleteGrp.setObjectName(u"btnDeleteGrp")
        self.btnDeleteGrp.setEnabled(True)
        self.btnDeleteGrp.setAutoDefault(False)

        self.hLayout_group.addWidget(self.btnDeleteGrp)


        self.vLayout_group.addLayout(self.hLayout_group)

        self.label = QLabel(DlgRegion)
        self.label.setObjectName(u"label")
        self.label.setGeometry(QRect(290, 210, 81, 17))
        self.label.setAutoFillBackground(True)
        self.layoutWidget1 = QWidget(DlgRegion)
        self.layoutWidget1.setObjectName(u"layoutWidget1")
        self.layoutWidget1.setGeometry(QRect(90, 170, 100, 38))
        self.horizontalLayout_2 = QHBoxLayout(self.layoutWidget1)
        self.horizontalLayout_2.setObjectName(u"horizontalLayout_2")
        self.horizontalLayout_2.setContentsMargins(0, 0, 0, 0)
        self.btnAdd = QPushButton(self.layoutWidget1)
        self.btnAdd.setObjectName(u"btnAdd")
        icon1 = QIcon()
        icon1.addFile(u":/Go-down.png", QSize(), QIcon.Normal, QIcon.Off)
        self.btnAdd.setIcon(icon1)
        self.btnAdd.setIconSize(QSize(24, 24))
        self.btnAdd.setAutoDefault(False)

        self.horizontalLayout_2.addWidget(self.btnAdd)

        self.btnDelete = QPushButton(self.layoutWidget1)
        self.btnDelete.setObjectName(u"btnDelete")
        icon2 = QIcon()
        icon2.addFile(u":/Edit-delete.png", QSize(), QIcon.Normal, QIcon.Off)
        self.btnDelete.setIcon(icon2)
        self.btnDelete.setIconSize(QSize(24, 24))
        self.btnDelete.setAutoDefault(False)

        self.horizontalLayout_2.addWidget(self.btnDelete)

        self.btnClose = QPushButton(DlgRegion)
        self.btnClose.setObjectName(u"btnClose")
        self.btnClose.setGeometry(QRect(290, 570, 227, 25))
        self.layoutWidget.raise_()
        self.tabRegion.raise_()
        self.frame.raise_()
        self.label.raise_()
        self.btnClose.raise_()
        QWidget.setTabOrder(self.tabRegion, self.point_tx0)
        QWidget.setTabOrder(self.point_tx0, self.point_tx1)
        QWidget.setTabOrder(self.point_tx1, self.line_tx0)
        QWidget.setTabOrder(self.line_tx0, self.line_tx1)
        QWidget.setTabOrder(self.line_tx1, self.line_tx2)
        QWidget.setTabOrder(self.line_tx2, self.line_tx3)
        QWidget.setTabOrder(self.line_tx3, self.line_tx4)
        QWidget.setTabOrder(self.line_tx4, self.rect_tx0)
        QWidget.setTabOrder(self.rect_tx0, self.rect_tx1)
        QWidget.setTabOrder(self.rect_tx1, self.rect_tx2)
        QWidget.setTabOrder(self.rect_tx2, self.rect_tx3)
        QWidget.setTabOrder(self.rect_tx3, self.circle_tx0)
        QWidget.setTabOrder(self.circle_tx0, self.circle_tx1)
        QWidget.setTabOrder(self.circle_tx1, self.circle_tx2)
        QWidget.setTabOrder(self.circle_tx2, self.ring_tx0)
        QWidget.setTabOrder(self.ring_tx0, self.ring_tx1)
        QWidget.setTabOrder(self.ring_tx1, self.ring_tx2)
        QWidget.setTabOrder(self.ring_tx2, self.ring_tx3)
        QWidget.setTabOrder(self.ring_tx3, self.sector_tx0)
        QWidget.setTabOrder(self.sector_tx0, self.sector_tx1)
        QWidget.setTabOrder(self.sector_tx1, self.sector_tx2)
        QWidget.setTabOrder(self.sector_tx2, self.sector_tx4)
        QWidget.setTabOrder(self.sector_tx4, self.sector_tx5)
        QWidget.setTabOrder(self.sector_tx5, self.rs_tx0)
        QWidget.setTabOrder(self.rs_tx0, self.rs_tx1)
        QWidget.setTabOrder(self.rs_tx1, self.rs_tx2)
        QWidget.setTabOrder(self.rs_tx2, self.rs_tx3)
        QWidget.setTabOrder(self.rs_tx3, self.rs_tx4)
        QWidget.setTabOrder(self.rs_tx4, self.rs_tx5)
        QWidget.setTabOrder(self.rs_tx5, self.btnAdd)
        QWidget.setTabOrder(self.btnAdd, self.btnDelete)
        QWidget.setTabOrder(self.btnDelete, self.btnAddGrp)
        QWidget.setTabOrder(self.btnAddGrp, self.btnDeleteGrp)
        QWidget.setTabOrder(self.btnDeleteGrp, self.btnClose)

        self.retranslateUi(DlgRegion)

        self.tabRegion.setCurrentIndex(2)


        QMetaObject.connectSlotsByName(DlgRegion)
    # setupUi

    def retranslateUi(self, DlgRegion):
        DlgRegion.setWindowTitle(QCoreApplication.translate("DlgRegion", u"Set Regions", None))
        self.tabPoint.setProperty("tabName", QCoreApplication.translate("DlgRegion", u"Point", None))
        self.rs_label0_10.setText(QCoreApplication.translate("DlgRegion", u"X0:", None))
        self.point_label0_18.setText(QCoreApplication.translate("DlgRegion", u"Y0:", None))
        self.point_tx1.setText("")
        self.tabRegion.setTabText(self.tabRegion.indexOf(self.tabPoint), QCoreApplication.translate("DlgRegion", u"Point", None))
        self.tabLine.setProperty("tabName", QCoreApplication.translate("DlgRegion", u"Line", None))
        self.rs_label0_5.setText(QCoreApplication.translate("DlgRegion", u"X0:", None))
        self.point_label0_14.setText(QCoreApplication.translate("DlgRegion", u"Y0:", None))
        self.line_tx1.setText("")
        self.rs_label0_6.setText(QCoreApplication.translate("DlgRegion", u"X1:", None))
        self.point_label0_16.setText(QCoreApplication.translate("DlgRegion", u"Y1:", None))
        self.label_15.setText(QCoreApplication.translate("DlgRegion", u"Width", None))
        self.tabRegion.setTabText(self.tabRegion.indexOf(self.tabLine), QCoreApplication.translate("DlgRegion", u"Line", None))
        self.tabRectangle.setProperty("tabName", QCoreApplication.translate("DlgRegion", u"Rectangle", None))
        self.rs_label0_8.setText(QCoreApplication.translate("DlgRegion", u"X0:", None))
        self.point_label0_15.setText(QCoreApplication.translate("DlgRegion", u"Y0:", None))
        self.rect_tx1.setText("")
        self.rs_label0_7.setText(QCoreApplication.translate("DlgRegion", u"X1:", None))
        self.point_label0_17.setText(QCoreApplication.translate("DlgRegion", u"Y1:", None))
        self.tabRegion.setTabText(self.tabRegion.indexOf(self.tabRectangle), QCoreApplication.translate("DlgRegion", u"Rectangle", None))
        self.tabCircle.setProperty("tabName", QCoreApplication.translate("DlgRegion", u"Circle", None))
        self.label_11.setText(QCoreApplication.translate("DlgRegion", u"Center", None))
        self.rs_label0_4.setText(QCoreApplication.translate("DlgRegion", u"X0:", None))
        self.point_label0_12.setText(QCoreApplication.translate("DlgRegion", u"Y0:", None))
        self.circle_tx1.setText("")
        self.label_10.setText(QCoreApplication.translate("DlgRegion", u"Radius", None))
        self.tabRegion.setTabText(self.tabRegion.indexOf(self.tabCircle), QCoreApplication.translate("DlgRegion", u"Circle", None))
        self.tabRing.setProperty("tabName", QCoreApplication.translate("DlgRegion", u"Ring", None))
        self.label_9.setText(QCoreApplication.translate("DlgRegion", u"Center", None))
        self.point_label0_13.setText(QCoreApplication.translate("DlgRegion", u"\u00b1", None))
        self.rs_label0_3.setText(QCoreApplication.translate("DlgRegion", u"X0:", None))
        self.ring_tx1.setText("")
        self.point_label0_11.setText(QCoreApplication.translate("DlgRegion", u"Y0:", None))
        self.label_8.setText(QCoreApplication.translate("DlgRegion", u"Radius", None))
        self.tabRegion.setTabText(self.tabRegion.indexOf(self.tabRing), QCoreApplication.translate("DlgRegion", u"Ring", None))
        self.tabSector.setProperty("tabName", QCoreApplication.translate("DlgRegion", u"Sector", None))
        self.label_6.setText(QCoreApplication.translate("DlgRegion", u"Center", None))
        self.rs_label0_2.setText(QCoreApplication.translate("DlgRegion", u"X0:", None))
        self.point_label0_7.setText(QCoreApplication.translate("DlgRegion", u"Y0:", None))
        self.sector_tx1.setText("")
        self.label_5.setText(QCoreApplication.translate("DlgRegion", u"Radius", None))
        self.label_7.setText(QCoreApplication.translate("DlgRegion", u"Angle", None))
        self.point_label0_10.setText(QCoreApplication.translate("DlgRegion", u"\u00b1", None))
        self.tabRegion.setTabText(self.tabRegion.indexOf(self.tabSector), QCoreApplication.translate("DlgRegion", u"Sector", None))
        self.tabRingSector.setProperty("tabName", QCoreApplication.translate("DlgRegion", u"Ring Sector", None))
        self.point_label0_8.setText(QCoreApplication.translate("DlgRegion", u"\u00b1", None))
        self.label_3.setText(QCoreApplication.translate("DlgRegion", u"Radius", None))
        self.rs_tx1.setText("")
        self.rs_label0.setText(QCoreApplication.translate("DlgRegion", u"X0:", None))
        self.point_label0_9.setText(QCoreApplication.translate("DlgRegion", u"\u00b1", None))
        self.label_4.setText(QCoreApplication.translate("DlgRegion", u"Angle", None))
        self.point_label0_6.setText(QCoreApplication.translate("DlgRegion", u"Y0:", None))
        self.label_2.setText(QCoreApplication.translate("DlgRegion", u"Center", None))
        self.tabRegion.setTabText(self.tabRegion.indexOf(self.tabRingSector), QCoreApplication.translate("DlgRegion", u"Ring Sector", None))
        self.btnAddGrp.setText(QCoreApplication.translate("DlgRegion", u"Add", None))
        self.btnDeleteGrp.setText(QCoreApplication.translate("DlgRegion", u"Delete", None))
        self.label.setText(QCoreApplication.translate("DlgRegion", u"Edit Groups", None))
        self.btnAdd.setText("")
        self.btnDelete.setText("")
        self.btnClose.setText(QCoreApplication.translate("DlgRegion", u"Close", None))
    # retranslateUi

try:
    import dg_region_rc
except:
    import uGao.dg_region_rc

################################################################################
## Form generated from reading UI file 'dg_slice.ui'
##
## Created by: Qt User Interface Compiler version 5.15.2
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide2.QtCore import *
from PySide2.QtGui import *
from PySide2.QtWidgets import *


class Ui_DlgSlice(object):
    def setupUi(self, DlgSlice):
        if not DlgSlice.objectName():
            DlgSlice.setObjectName(u"DlgSlice")
        DlgSlice.resize(293, 287)
        icon = QIcon()
        icon.addFile(u":/ugao_icon.png", QSize(), QIcon.Normal, QIcon.Off)
        DlgSlice.setWindowIcon(icon)
        self.buttonBox = QDialogButtonBox(DlgSlice)
        self.buttonBox.setObjectName(u"buttonBox")
        self.buttonBox.setGeometry(QRect(10, 250, 271, 32))
        self.buttonBox.setOrientation(Qt.Horizontal)
        self.buttonBox.setStandardButtons(QDialogButtonBox.Apply|QDialogButtonBox.Close|QDialogButtonBox.Reset)
        self.groupBox = QGroupBox(DlgSlice)
        self.groupBox.setObjectName(u"groupBox")
        self.groupBox.setGeometry(QRect(10, 0, 271, 121))
        self.gridLayoutWidget = QWidget(self.groupBox)
        self.gridLayoutWidget.setObjectName(u"gridLayoutWidget")
        self.gridLayoutWidget.setGeometry(QRect(10, 20, 251, 95))
        self.gridLayout = QGridLayout(self.gridLayoutWidget)
        self.gridLayout.setObjectName(u"gridLayout")
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.radio_yvalue = QRadioButton(self.gridLayoutWidget)
        self.radio_yvalue.setObjectName(u"radio_yvalue")
        self.radio_yvalue.setChecked(True)

        self.gridLayout.addWidget(self.radio_yvalue, 0, 0, 1, 1)

        self.txt_y_center = QLineEdit(self.gridLayoutWidget)
        self.txt_y_center.setObjectName(u"txt_y_center")

        self.gridLayout.addWidget(self.txt_y_center, 0, 1, 1, 1)

        self.txt_y_start = QLineEdit(self.gridLayoutWidget)
        self.txt_y_start.setObjectName(u"txt_y_start")
        self.txt_y_start.setEnabled(False)

        self.gridLayout.addWidget(self.txt_y_start, 1, 1, 1, 1)

        self.label = QLabel(self.gridLayoutWidget)
        self.label.setObjectName(u"label")
        self.label.setAlignment(Qt.AlignCenter)

        self.gridLayout.addWidget(self.label, 0, 2, 1, 1)

        self.radio_yrange = QRadioButton(self.gridLayoutWidget)
        self.radio_yrange.setObjectName(u"radio_yrange")

        self.gridLayout.addWidget(self.radio_yrange, 1, 0, 1, 1)

        self.label_2 = QLabel(self.gridLayoutWidget)
        self.label_2.setObjectName(u"label_2")
        self.label_2.setEnabled(False)
        self.label_2.setAlignment(Qt.AlignCenter)

        self.gridLayout.addWidget(self.label_2, 1, 2, 1, 1)

        self.txt_y_width = QLineEdit(self.gridLayoutWidget)
        self.txt_y_width.setObjectName(u"txt_y_width")

        self.gridLayout.addWidget(self.txt_y_width, 0, 3, 1, 1)

        self.txt_y_end = QLineEdit(self.gridLayoutWidget)
        self.txt_y_end.setObjectName(u"txt_y_end")
        self.txt_y_end.setEnabled(False)

        self.gridLayout.addWidget(self.txt_y_end, 1, 3, 1, 1)

        self.cb_sliceXbin = QCheckBox(self.gridLayoutWidget)
        self.cb_sliceXbin.setObjectName(u"cb_sliceXbin")

        self.gridLayout.addWidget(self.cb_sliceXbin, 2, 0, 1, 1)

        self.txt_xbin = QLineEdit(self.gridLayoutWidget)
        self.txt_xbin.setObjectName(u"txt_xbin")

        self.gridLayout.addWidget(self.txt_xbin, 2, 1, 1, 1)

        self.groupBox_2 = QGroupBox(DlgSlice)
        self.groupBox_2.setObjectName(u"groupBox_2")
        self.groupBox_2.setGeometry(QRect(10, 120, 271, 121))
        self.gridLayoutWidget_2 = QWidget(self.groupBox_2)
        self.gridLayoutWidget_2.setObjectName(u"gridLayoutWidget_2")
        self.gridLayoutWidget_2.setGeometry(QRect(10, 20, 251, 95))
        self.gridLayout_2 = QGridLayout(self.gridLayoutWidget_2)
        self.gridLayout_2.setObjectName(u"gridLayout_2")
        self.gridLayout_2.setContentsMargins(0, 0, 0, 0)
        self.label_3 = QLabel(self.gridLayoutWidget_2)
        self.label_3.setObjectName(u"label_3")
        self.label_3.setAlignment(Qt.AlignCenter)

        self.gridLayout_2.addWidget(self.label_3, 0, 2, 1, 1)

        self.label_4 = QLabel(self.gridLayoutWidget_2)
        self.label_4.setObjectName(u"label_4")
        self.label_4.setEnabled(False)
        self.label_4.setAlignment(Qt.AlignCenter)

        self.gridLayout_2.addWidget(self.label_4, 1, 2, 1, 1)

        self.radio_xvalue = QRadioButton(self.gridLayoutWidget_2)
        self.radio_xvalue.setObjectName(u"radio_xvalue")
        self.radio_xvalue.setChecked(True)

        self.gridLayout_2.addWidget(self.radio_xvalue, 0, 0, 1, 1)

        self.txt_x_center = QLineEdit(self.gridLayoutWidget_2)
        self.txt_x_center.setObjectName(u"txt_x_center")

        self.gridLayout_2.addWidget(self.txt_x_center, 0, 1, 1, 1)

        self.txt_x_start = QLineEdit(self.gridLayoutWidget_2)
        self.txt_x_start.setObjectName(u"txt_x_start")
        self.txt_x_start.setEnabled(False)

        self.gridLayout_2.addWidget(self.txt_x_start, 1, 1, 1, 1)

        self.radio_xrange = QRadioButton(self.gridLayoutWidget_2)
        self.radio_xrange.setObjectName(u"radio_xrange")

        self.gridLayout_2.addWidget(self.radio_xrange, 1, 0, 1, 1)

        self.txt_x_width = QLineEdit(self.gridLayoutWidget_2)
        self.txt_x_width.setObjectName(u"txt_x_width")

        self.gridLayout_2.addWidget(self.txt_x_width, 0, 3, 1, 1)

        self.txt_x_end = QLineEdit(self.gridLayoutWidget_2)
        self.txt_x_end.setObjectName(u"txt_x_end")
        self.txt_x_end.setEnabled(False)

        self.gridLayout_2.addWidget(self.txt_x_end, 1, 3, 1, 1)

        self.cb_sliceYbin = QCheckBox(self.gridLayoutWidget_2)
        self.cb_sliceYbin.setObjectName(u"cb_sliceYbin")

        self.gridLayout_2.addWidget(self.cb_sliceYbin, 2, 0, 1, 1)

        self.txt_ybin = QLineEdit(self.gridLayoutWidget_2)
        self.txt_ybin.setObjectName(u"txt_ybin")

        self.gridLayout_2.addWidget(self.txt_ybin, 2, 1, 1, 1)

        QWidget.setTabOrder(self.radio_yvalue, self.txt_y_center)
        QWidget.setTabOrder(self.txt_y_center, self.txt_y_width)
        QWidget.setTabOrder(self.txt_y_width, self.radio_yrange)
        QWidget.setTabOrder(self.radio_yrange, self.txt_y_start)
        QWidget.setTabOrder(self.txt_y_start, self.txt_y_end)
        QWidget.setTabOrder(self.txt_y_end, self.radio_xvalue)
        QWidget.setTabOrder(self.radio_xvalue, self.txt_x_center)
        QWidget.setTabOrder(self.txt_x_center, self.txt_x_width)
        QWidget.setTabOrder(self.txt_x_width, self.radio_xrange)
        QWidget.setTabOrder(self.radio_xrange, self.txt_x_start)
        QWidget.setTabOrder(self.txt_x_start, self.txt_x_end)
        QWidget.setTabOrder(self.txt_x_end, self.buttonBox)

        self.retranslateUi(DlgSlice)
        self.buttonBox.accepted.connect(DlgSlice.accept)
        self.buttonBox.rejected.connect(DlgSlice.reject)
        self.radio_yrange.toggled.connect(self.txt_y_start.setEnabled)
        self.radio_yrange.toggled.connect(self.txt_y_end.setEnabled)
        self.radio_yvalue.toggled.connect(self.txt_y_center.setEnabled)
        self.radio_yvalue.toggled.connect(self.txt_y_width.setEnabled)
        self.radio_xvalue.toggled.connect(self.txt_x_center.setEnabled)
        self.radio_xvalue.toggled.connect(self.txt_x_width.setEnabled)
        self.radio_xrange.toggled.connect(self.txt_x_start.setEnabled)
        self.radio_xrange.toggled.connect(self.txt_x_end.setEnabled)
        self.radio_yrange.toggled.connect(self.label_2.setEnabled)
        self.radio_yvalue.toggled.connect(self.label.setEnabled)
        self.radio_xvalue.toggled.connect(self.label_3.setEnabled)
        self.radio_xrange.toggled.connect(self.label_4.setEnabled)

        QMetaObject.connectSlotsByName(DlgSlice)
    # setupUi

    def retranslateUi(self, DlgSlice):
        DlgSlice.setWindowTitle(QCoreApplication.translate("DlgSlice", u"Slice Regions", None))
        self.groupBox.setTitle(QCoreApplication.translate("DlgSlice", u"X-Intensity Graph", None))
        self.radio_yvalue.setText(QCoreApplication.translate("DlgSlice", u"Y value", None))
        self.txt_y_start.setText("")
        self.label.setText(QCoreApplication.translate("DlgSlice", u"\u00b1", None))
        self.radio_yrange.setText(QCoreApplication.translate("DlgSlice", u"Y range", None))
        self.label_2.setText(QCoreApplication.translate("DlgSlice", u"-", None))
        self.cb_sliceXbin.setText(QCoreApplication.translate("DlgSlice", u"rebin", None))
        self.groupBox_2.setTitle(QCoreApplication.translate("DlgSlice", u"Y-Intensity Graph", None))
        self.label_3.setText(QCoreApplication.translate("DlgSlice", u"\u00b1", None))
        self.label_4.setText(QCoreApplication.translate("DlgSlice", u"-", None))
        self.radio_xvalue.setText(QCoreApplication.translate("DlgSlice", u"X value", None))
        self.txt_x_start.setText("")
        self.radio_xrange.setText(QCoreApplication.translate("DlgSlice", u"X range", None))
        self.cb_sliceYbin.setText(QCoreApplication.translate("DlgSlice", u"rebin", None))
    # retranslateUi


################################################################################
## Form generated from reading UI file 'dg_view_prms.ui'
##
## Created by: Qt User Interface Compiler version 5.15.2
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide2.QtCore import *
from PySide2.QtGui import *
from PySide2.QtWidgets import *


class Ui_DlgViewPrms(object):
    def setupUi(self, DlgViewPrms):
        if not DlgViewPrms.objectName():
            DlgViewPrms.setObjectName(u"DlgViewPrms")
        DlgViewPrms.resize(440, 600)
        font = QFont()
        font.setFamily(u"Sans Serif")
        font.setPointSize(9)
        DlgViewPrms.setFont(font)
        icon = QIcon()
        icon.addFile(u":/ugao_icon.png", QSize(), QIcon.Normal, QIcon.Off)
        DlgViewPrms.setWindowIcon(icon)
        self.tabWidget = QTabWidget(DlgViewPrms)
        self.tabWidget.setObjectName(u"tabWidget")
        self.tabWidget.setGeometry(QRect(10, 10, 421, 191))
        self.tab = QWidget()
        self.tab.setObjectName(u"tab")
        self.layoutWidget_2 = QWidget(self.tab)
        self.layoutWidget_2.setObjectName(u"layoutWidget_2")
        self.layoutWidget_2.setGeometry(QRect(10, 50, 401, 37))
        self.horizontalLayout_9 = QHBoxLayout(self.layoutWidget_2)
        self.horizontalLayout_9.setSpacing(6)
        self.horizontalLayout_9.setContentsMargins(11, 11, 11, 11)
        self.horizontalLayout_9.setObjectName(u"horizontalLayout_9")
        self.horizontalLayout_9.setSizeConstraint(QLayout.SetNoConstraint)
        self.horizontalLayout_9.setContentsMargins(0, 0, 0, 0)
        self.check_x_auto_range = QCheckBox(self.layoutWidget_2)
        self.check_x_auto_range.setObjectName(u"check_x_auto_range")
        self.check_x_auto_range.setChecked(True)

        self.horizontalLayout_9.addWidget(self.check_x_auto_range)

        self.horizontalLayout_10 = QHBoxLayout()
        self.horizontalLayout_10.setSpacing(6)
        self.horizontalLayout_10.setObjectName(u"horizontalLayout_10")
        self.label_12 = QLabel(self.layoutWidget_2)
        self.label_12.setObjectName(u"label_12")
        self.label_12.setEnabled(False)

        self.horizontalLayout_10.addWidget(self.label_12)

        self.txt_x_min = QLineEdit(self.layoutWidget_2)
        self.txt_x_min.setObjectName(u"txt_x_min")
        self.txt_x_min.setEnabled(False)

        self.horizontalLayout_10.addWidget(self.txt_x_min)

        self.label_13 = QLabel(self.layoutWidget_2)
        self.label_13.setObjectName(u"label_13")
        self.label_13.setEnabled(False)

        self.horizontalLayout_10.addWidget(self.label_13)

        self.txt_x_max = QLineEdit(self.layoutWidget_2)
        self.txt_x_max.setObjectName(u"txt_x_max")
        self.txt_x_max.setEnabled(False)

        self.horizontalLayout_10.addWidget(self.txt_x_max)


        self.horizontalLayout_9.addLayout(self.horizontalLayout_10)

        self.check_x_log = QCheckBox(self.tab)
        self.check_x_log.setObjectName(u"check_x_log")
        self.check_x_log.setGeometry(QRect(230, 10, 97, 22))
        self.check_x_inv = QCheckBox(self.tab)
        self.check_x_inv.setObjectName(u"check_x_inv")
        self.check_x_inv.setGeometry(QRect(330, 10, 91, 22))
        self.layoutWidget = QWidget(self.tab)
        self.layoutWidget.setObjectName(u"layoutWidget")
        self.layoutWidget.setGeometry(QRect(10, 120, 407, 35))
        self.horizontalLayout_7 = QHBoxLayout(self.layoutWidget)
        self.horizontalLayout_7.setSpacing(6)
        self.horizontalLayout_7.setContentsMargins(11, 11, 11, 11)
        self.horizontalLayout_7.setObjectName(u"horizontalLayout_7")
        self.horizontalLayout_7.setSizeConstraint(QLayout.SetDefaultConstraint)
        self.horizontalLayout_7.setContentsMargins(0, 0, 0, 0)
        self.check_x_auto_tick = QCheckBox(self.layoutWidget)
        self.check_x_auto_tick.setObjectName(u"check_x_auto_tick")
        self.check_x_auto_tick.setChecked(True)

        self.horizontalLayout_7.addWidget(self.check_x_auto_tick)

        self.horizontalSpacer_4 = QSpacerItem(10, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)

        self.horizontalLayout_7.addItem(self.horizontalSpacer_4)

        self.label_9 = QLabel(self.layoutWidget)
        self.label_9.setObjectName(u"label_9")
        self.label_9.setEnabled(False)

        self.horizontalLayout_7.addWidget(self.label_9)

        self.combo_x_format = QComboBox(self.layoutWidget)
        self.combo_x_format.setObjectName(u"combo_x_format")

        self.horizontalLayout_7.addWidget(self.combo_x_format)

        self.horizontalSpacer_5 = QSpacerItem(10, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)

        self.horizontalLayout_7.addItem(self.horizontalSpacer_5)

        self.label_10 = QLabel(self.layoutWidget)
        self.label_10.setObjectName(u"label_10")
        self.label_10.setEnabled(False)

        self.horizontalLayout_7.addWidget(self.label_10)

        self.spin_x_prec = QSpinBox(self.layoutWidget)
        self.spin_x_prec.setObjectName(u"spin_x_prec")
        self.spin_x_prec.setEnabled(False)
        self.spin_x_prec.setMaximum(10)
        self.spin_x_prec.setValue(3)

        self.horizontalLayout_7.addWidget(self.spin_x_prec)

        self.label_8 = QLabel(self.tab)
        self.label_8.setObjectName(u"label_8")
        self.label_8.setGeometry(QRect(10, 100, 120, 16))
        self.txt_x_label = QLineEdit(self.tab)
        self.txt_x_label.setObjectName(u"txt_x_label")
        self.txt_x_label.setGeometry(QRect(50, 10, 111, 26))
        self.txt_x_unit = QLineEdit(self.tab)
        self.txt_x_unit.setObjectName(u"txt_x_unit")
        self.txt_x_unit.setGeometry(QRect(170, 10, 51, 26))
        self.label_14 = QLabel(self.tab)
        self.label_14.setObjectName(u"label_14")
        self.label_14.setGeometry(QRect(10, 10, 41, 26))
        self.tabWidget.addTab(self.tab, "")
        self.tab_2 = QWidget()
        self.tab_2.setObjectName(u"tab_2")
        self.layoutWidget1 = QWidget(self.tab_2)
        self.layoutWidget1.setObjectName(u"layoutWidget1")
        self.layoutWidget1.setGeometry(QRect(10, 50, 401, 37))
        self.horizontalLayout_3 = QHBoxLayout(self.layoutWidget1)
        self.horizontalLayout_3.setSpacing(6)
        self.horizontalLayout_3.setContentsMargins(11, 11, 11, 11)
        self.horizontalLayout_3.setObjectName(u"horizontalLayout_3")
        self.horizontalLayout_3.setSizeConstraint(QLayout.SetNoConstraint)
        self.horizontalLayout_3.setContentsMargins(0, 0, 0, 0)
        self.check_y_auto_range = QCheckBox(self.layoutWidget1)
        self.check_y_auto_range.setObjectName(u"check_y_auto_range")
        self.check_y_auto_range.setChecked(True)

        self.horizontalLayout_3.addWidget(self.check_y_auto_range)

        self.horizontalLayout_2 = QHBoxLayout()
        self.horizontalLayout_2.setSpacing(6)
        self.horizontalLayout_2.setObjectName(u"horizontalLayout_2")
        self.label_4 = QLabel(self.layoutWidget1)
        self.label_4.setObjectName(u"label_4")
        self.label_4.setEnabled(False)

        self.horizontalLayout_2.addWidget(self.label_4)

        self.txt_y_min = QLineEdit(self.layoutWidget1)
        self.txt_y_min.setObjectName(u"txt_y_min")
        self.txt_y_min.setEnabled(False)

        self.horizontalLayout_2.addWidget(self.txt_y_min)

        self.label_5 = QLabel(self.layoutWidget1)
        self.label_5.setObjectName(u"label_5")
        self.label_5.setEnabled(False)

        self.horizontalLayout_2.addWidget(self.label_5)

        self.txt_y_max = QLineEdit(self.layoutWidget1)
        self.txt_y_max.setObjectName(u"txt_y_max")
        self.txt_y_max.setEnabled(False)

        self.horizontalLayout_2.addWidget(self.txt_y_max)


        self.horizontalLayout_3.addLayout(self.horizontalLayout_2)

        self.check_y_log = QCheckBox(self.tab_2)
        self.check_y_log.setObjectName(u"check_y_log")
        self.check_y_log.setGeometry(QRect(230, 10, 97, 22))
        self.check_y_inv = QCheckBox(self.tab_2)
        self.check_y_inv.setObjectName(u"check_y_inv")
        self.check_y_inv.setGeometry(QRect(330, 10, 97, 22))
        self.layoutWidget2 = QWidget(self.tab_2)
        self.layoutWidget2.setObjectName(u"layoutWidget2")
        self.layoutWidget2.setGeometry(QRect(10, 120, 407, 35))
        self.horizontalLayout_6 = QHBoxLayout(self.layoutWidget2)
        self.horizontalLayout_6.setSpacing(6)
        self.horizontalLayout_6.setContentsMargins(11, 11, 11, 11)
        self.horizontalLayout_6.setObjectName(u"horizontalLayout_6")
        self.horizontalLayout_6.setSizeConstraint(QLayout.SetDefaultConstraint)
        self.horizontalLayout_6.setContentsMargins(0, 0, 0, 0)
        self.check_y_auto_tick = QCheckBox(self.layoutWidget2)
        self.check_y_auto_tick.setObjectName(u"check_y_auto_tick")
        self.check_y_auto_tick.setChecked(True)

        self.horizontalLayout_6.addWidget(self.check_y_auto_tick)

        self.horizontalSpacer_2 = QSpacerItem(10, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)

        self.horizontalLayout_6.addItem(self.horizontalSpacer_2)

        self.label_6 = QLabel(self.layoutWidget2)
        self.label_6.setObjectName(u"label_6")
        self.label_6.setEnabled(False)

        self.horizontalLayout_6.addWidget(self.label_6)

        self.combo_y_format = QComboBox(self.layoutWidget2)
        self.combo_y_format.setObjectName(u"combo_y_format")

        self.horizontalLayout_6.addWidget(self.combo_y_format)

        self.horizontalSpacer_3 = QSpacerItem(10, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)

        self.horizontalLayout_6.addItem(self.horizontalSpacer_3)

        self.label_7 = QLabel(self.layoutWidget2)
        self.label_7.setObjectName(u"label_7")
        self.label_7.setEnabled(False)

        self.horizontalLayout_6.addWidget(self.label_7)

        self.spin_y_prec = QSpinBox(self.layoutWidget2)
        self.spin_y_prec.setObjectName(u"spin_y_prec")
        self.spin_y_prec.setEnabled(False)
        self.spin_y_prec.setMaximum(10)
        self.spin_y_prec.setValue(3)

        self.horizontalLayout_6.addWidget(self.spin_y_prec)

        self.label_11 = QLabel(self.tab_2)
        self.label_11.setObjectName(u"label_11")
        self.label_11.setGeometry(QRect(10, 100, 120, 16))
        self.txt_y_label = QLineEdit(self.tab_2)
        self.txt_y_label.setObjectName(u"txt_y_label")
        self.txt_y_label.setGeometry(QRect(50, 10, 111, 26))
        self.txt_y_unit = QLineEdit(self.tab_2)
        self.txt_y_unit.setObjectName(u"txt_y_unit")
        self.txt_y_unit.setGeometry(QRect(170, 10, 51, 26))
        self.label_3 = QLabel(self.tab_2)
        self.label_3.setObjectName(u"label_3")
        self.label_3.setGeometry(QRect(10, 10, 41, 26))
        self.tabWidget.addTab(self.tab_2, "")
        self.tabWidget_2 = QTabWidget(DlgViewPrms)
        self.tabWidget_2.setObjectName(u"tabWidget_2")
        self.tabWidget_2.setGeometry(QRect(10, 220, 421, 281))
        self.tab_3 = QWidget()
        self.tab_3.setObjectName(u"tab_3")
        self.layoutWidget3 = QWidget(self.tab_3)
        self.layoutWidget3.setObjectName(u"layoutWidget3")
        self.layoutWidget3.setGeometry(QRect(10, 10, 401, 231))
        self.verticalLayout = QVBoxLayout(self.layoutWidget3)
        self.verticalLayout.setSpacing(6)
        self.verticalLayout.setContentsMargins(11, 11, 11, 11)
        self.verticalLayout.setObjectName(u"verticalLayout")
        self.verticalLayout.setSizeConstraint(QLayout.SetNoConstraint)
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.formLayout_2 = QFormLayout()
        self.formLayout_2.setSpacing(6)
        self.formLayout_2.setObjectName(u"formLayout_2")
        self.formLayout_2.setSizeConstraint(QLayout.SetNoConstraint)
        self.label = QLabel(self.layoutWidget3)
        self.label.setObjectName(u"label")

        self.formLayout_2.setWidget(0, QFormLayout.LabelRole, self.label)

        self.txt_title = QLineEdit(self.layoutWidget3)
        self.txt_title.setObjectName(u"txt_title")

        self.formLayout_2.setWidget(0, QFormLayout.FieldRole, self.txt_title)

        self.label_2 = QLabel(self.layoutWidget3)
        self.label_2.setObjectName(u"label_2")

        self.formLayout_2.setWidget(1, QFormLayout.LabelRole, self.label_2)

        self.txt_comment = QPlainTextEdit(self.layoutWidget3)
        self.txt_comment.setObjectName(u"txt_comment")

        self.formLayout_2.setWidget(1, QFormLayout.FieldRole, self.txt_comment)


        self.verticalLayout.addLayout(self.formLayout_2)

        self.horizontalLayout_11 = QHBoxLayout()
        self.horizontalLayout_11.setSpacing(6)
        self.horizontalLayout_11.setObjectName(u"horizontalLayout_11")
        self.label_24 = QLabel(self.layoutWidget3)
        self.label_24.setObjectName(u"label_24")

        self.horizontalLayout_11.addWidget(self.label_24)

        self.txt_width = QLineEdit(self.layoutWidget3)
        self.txt_width.setObjectName(u"txt_width")

        self.horizontalLayout_11.addWidget(self.txt_width)

        self.label_25 = QLabel(self.layoutWidget3)
        self.label_25.setObjectName(u"label_25")

        self.horizontalLayout_11.addWidget(self.label_25)

        self.txt_height = QLineEdit(self.layoutWidget3)
        self.txt_height.setObjectName(u"txt_height")

        self.horizontalLayout_11.addWidget(self.txt_height)

        self.btn_winsize = QPushButton(self.layoutWidget3)
        self.btn_winsize.setObjectName(u"btn_winsize")

        self.horizontalLayout_11.addWidget(self.btn_winsize)


        self.verticalLayout.addLayout(self.horizontalLayout_11)

        self.horizontalLayout_4 = QHBoxLayout()
        self.horizontalLayout_4.setSpacing(6)
        self.horizontalLayout_4.setObjectName(u"horizontalLayout_4")
        self.check_auto_update = QCheckBox(self.layoutWidget3)
        self.check_auto_update.setObjectName(u"check_auto_update")
        self.check_auto_update.setChecked(True)

        self.horizontalLayout_4.addWidget(self.check_auto_update)

        self.check_trans = QCheckBox(self.layoutWidget3)
        self.check_trans.setObjectName(u"check_trans")
        self.check_trans.setChecked(False)

        self.horizontalLayout_4.addWidget(self.check_trans)


        self.verticalLayout.addLayout(self.horizontalLayout_4)

        self.horizontalLayout_16 = QHBoxLayout()
        self.horizontalLayout_16.setSpacing(6)
        self.horizontalLayout_16.setObjectName(u"horizontalLayout_16")
        self.label_27 = QLabel(self.layoutWidget3)
        self.label_27.setObjectName(u"label_27")

        self.horizontalLayout_16.addWidget(self.label_27)

        self.rb_isAveSlice = QRadioButton(self.layoutWidget3)
        self.rb_isAveSlice.setObjectName(u"rb_isAveSlice")
        self.rb_isAveSlice.setChecked(True)

        self.horizontalLayout_16.addWidget(self.rb_isAveSlice)

        self.rb_isSumSlice = QRadioButton(self.layoutWidget3)
        self.rb_isSumSlice.setObjectName(u"rb_isSumSlice")

        self.horizontalLayout_16.addWidget(self.rb_isSumSlice)


        self.verticalLayout.addLayout(self.horizontalLayout_16)

        self.tabWidget_2.addTab(self.tab_3, "")
        self.tab_4 = QWidget()
        self.tab_4.setObjectName(u"tab_4")
        self.verticalLayoutWidget_2 = QWidget(self.tab_4)
        self.verticalLayoutWidget_2.setObjectName(u"verticalLayoutWidget_2")
        self.verticalLayoutWidget_2.setGeometry(QRect(10, 10, 401, 241))
        self.verticalLayout_4 = QVBoxLayout(self.verticalLayoutWidget_2)
        self.verticalLayout_4.setSpacing(6)
        self.verticalLayout_4.setContentsMargins(11, 11, 11, 11)
        self.verticalLayout_4.setObjectName(u"verticalLayout_4")
        self.verticalLayout_4.setSizeConstraint(QLayout.SetNoConstraint)
        self.verticalLayout_4.setContentsMargins(0, 0, 0, 0)
        self.grp_grid_h = QGroupBox(self.verticalLayoutWidget_2)
        self.grp_grid_h.setObjectName(u"grp_grid_h")
        self.grp_grid_h.setEnabled(True)
        self.grp_grid_h.setCheckable(True)
        self.gridLayoutWidget_2 = QWidget(self.grp_grid_h)
        self.gridLayoutWidget_2.setObjectName(u"gridLayoutWidget_2")
        self.gridLayoutWidget_2.setGeometry(QRect(9, 20, 381, 71))
        self.gridLayout_2 = QGridLayout(self.gridLayoutWidget_2)
        self.gridLayout_2.setSpacing(0)
        self.gridLayout_2.setContentsMargins(11, 11, 11, 11)
        self.gridLayout_2.setObjectName(u"gridLayout_2")
        self.gridLayout_2.setSizeConstraint(QLayout.SetNoConstraint)
        self.gridLayout_2.setContentsMargins(0, 0, 0, 0)
        self.label_31 = QLabel(self.gridLayoutWidget_2)
        self.label_31.setObjectName(u"label_31")
        sizePolicy = QSizePolicy(QSizePolicy.Preferred, QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_31.sizePolicy().hasHeightForWidth())
        self.label_31.setSizePolicy(sizePolicy)
        self.label_31.setMaximumSize(QSize(60, 16777215))

        self.gridLayout_2.addWidget(self.label_31, 0, 0, 1, 1)

        self.txt_h_interval = QLineEdit(self.gridLayoutWidget_2)
        self.txt_h_interval.setObjectName(u"txt_h_interval")
        sizePolicy1 = QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed)
        sizePolicy1.setHorizontalStretch(0)
        sizePolicy1.setVerticalStretch(0)
        sizePolicy1.setHeightForWidth(self.txt_h_interval.sizePolicy().hasHeightForWidth())
        self.txt_h_interval.setSizePolicy(sizePolicy1)
        self.txt_h_interval.setMaximumSize(QSize(60, 16777215))

        self.gridLayout_2.addWidget(self.txt_h_interval, 1, 4, 1, 1)

        self.txt_grid_width_h = QLineEdit(self.gridLayoutWidget_2)
        self.txt_grid_width_h.setObjectName(u"txt_grid_width_h")
        sizePolicy1.setHeightForWidth(self.txt_grid_width_h.sizePolicy().hasHeightForWidth())
        self.txt_grid_width_h.setSizePolicy(sizePolicy1)
        self.txt_grid_width_h.setMaximumSize(QSize(60, 16777215))
        self.txt_grid_width_h.setMaxLength(3)

        self.gridLayout_2.addWidget(self.txt_grid_width_h, 0, 4, 1, 1)

        self.cb_grid_color_h = QComboBox(self.gridLayoutWidget_2)
        self.cb_grid_color_h.setObjectName(u"cb_grid_color_h")
        sizePolicy1.setHeightForWidth(self.cb_grid_color_h.sizePolicy().hasHeightForWidth())
        self.cb_grid_color_h.setSizePolicy(sizePolicy1)
        self.cb_grid_color_h.setMaximumSize(QSize(80, 16777215))

        self.gridLayout_2.addWidget(self.cb_grid_color_h, 0, 1, 1, 1)

        self.label_32 = QLabel(self.gridLayoutWidget_2)
        self.label_32.setObjectName(u"label_32")
        self.label_32.setMaximumSize(QSize(60, 16777215))

        self.gridLayout_2.addWidget(self.label_32, 1, 0, 1, 1)

        self.cb_grid_style_h = QComboBox(self.gridLayoutWidget_2)
        self.cb_grid_style_h.setObjectName(u"cb_grid_style_h")
        sizePolicy1.setHeightForWidth(self.cb_grid_style_h.sizePolicy().hasHeightForWidth())
        self.cb_grid_style_h.setSizePolicy(sizePolicy1)
        self.cb_grid_style_h.setMaximumSize(QSize(80, 16777215))

        self.gridLayout_2.addWidget(self.cb_grid_style_h, 1, 1, 1, 1)

        self.label_15 = QLabel(self.gridLayoutWidget_2)
        self.label_15.setObjectName(u"label_15")
        self.label_15.setMaximumSize(QSize(60, 16777215))

        self.gridLayout_2.addWidget(self.label_15, 1, 3, 1, 1)

        self.horizontalSpacer = QSpacerItem(20, 20, QSizePolicy.Fixed, QSizePolicy.Minimum)

        self.gridLayout_2.addItem(self.horizontalSpacer, 0, 2, 1, 1)

        self.label_33 = QLabel(self.gridLayoutWidget_2)
        self.label_33.setObjectName(u"label_33")
        self.label_33.setMaximumSize(QSize(60, 16777215))

        self.gridLayout_2.addWidget(self.label_33, 0, 3, 1, 1)


        self.verticalLayout_4.addWidget(self.grp_grid_h)

        self.grp_grid_v = QGroupBox(self.verticalLayoutWidget_2)
        self.grp_grid_v.setObjectName(u"grp_grid_v")
        self.grp_grid_v.setEnabled(True)
        self.grp_grid_v.setCheckable(True)
        self.gridLayoutWidget_3 = QWidget(self.grp_grid_v)
        self.gridLayoutWidget_3.setObjectName(u"gridLayoutWidget_3")
        self.gridLayoutWidget_3.setGeometry(QRect(10, 20, 381, 75))
        self.gridLayout_3 = QGridLayout(self.gridLayoutWidget_3)
        self.gridLayout_3.setSpacing(0)
        self.gridLayout_3.setContentsMargins(11, 11, 11, 11)
        self.gridLayout_3.setObjectName(u"gridLayout_3")
        self.gridLayout_3.setSizeConstraint(QLayout.SetNoConstraint)
        self.gridLayout_3.setContentsMargins(0, 0, 0, 0)
        self.cb_grid_color_v = QComboBox(self.gridLayoutWidget_3)
        self.cb_grid_color_v.setObjectName(u"cb_grid_color_v")
        sizePolicy1.setHeightForWidth(self.cb_grid_color_v.sizePolicy().hasHeightForWidth())
        self.cb_grid_color_v.setSizePolicy(sizePolicy1)
        self.cb_grid_color_v.setMaximumSize(QSize(80, 16777215))

        self.gridLayout_3.addWidget(self.cb_grid_color_v, 0, 1, 1, 1)

        self.cb_grid_style_v = QComboBox(self.gridLayoutWidget_3)
        self.cb_grid_style_v.setObjectName(u"cb_grid_style_v")
        sizePolicy1.setHeightForWidth(self.cb_grid_style_v.sizePolicy().hasHeightForWidth())
        self.cb_grid_style_v.setSizePolicy(sizePolicy1)
        self.cb_grid_style_v.setMaximumSize(QSize(80, 16777215))

        self.gridLayout_3.addWidget(self.cb_grid_style_v, 1, 1, 1, 1)

        self.label_36 = QLabel(self.gridLayoutWidget_3)
        self.label_36.setObjectName(u"label_36")
        self.label_36.setMaximumSize(QSize(60, 16777215))

        self.gridLayout_3.addWidget(self.label_36, 0, 3, 1, 1)

        self.txt_grid_width_v = QLineEdit(self.gridLayoutWidget_3)
        self.txt_grid_width_v.setObjectName(u"txt_grid_width_v")
        sizePolicy1.setHeightForWidth(self.txt_grid_width_v.sizePolicy().hasHeightForWidth())
        self.txt_grid_width_v.setSizePolicy(sizePolicy1)
        self.txt_grid_width_v.setMaximumSize(QSize(60, 16777215))
        self.txt_grid_width_v.setMaxLength(3)

        self.gridLayout_3.addWidget(self.txt_grid_width_v, 0, 4, 1, 1)

        self.label_16 = QLabel(self.gridLayoutWidget_3)
        self.label_16.setObjectName(u"label_16")
        self.label_16.setMaximumSize(QSize(60, 16777215))

        self.gridLayout_3.addWidget(self.label_16, 1, 3, 1, 1)

        self.txt_v_interval = QLineEdit(self.gridLayoutWidget_3)
        self.txt_v_interval.setObjectName(u"txt_v_interval")
        sizePolicy1.setHeightForWidth(self.txt_v_interval.sizePolicy().hasHeightForWidth())
        self.txt_v_interval.setSizePolicy(sizePolicy1)
        self.txt_v_interval.setMaximumSize(QSize(60, 16777215))

        self.gridLayout_3.addWidget(self.txt_v_interval, 1, 4, 1, 1)

        self.horizontalSpacer_7 = QSpacerItem(20, 20, QSizePolicy.Fixed, QSizePolicy.Minimum)

        self.gridLayout_3.addItem(self.horizontalSpacer_7, 0, 2, 1, 1)

        self.label_35 = QLabel(self.gridLayoutWidget_3)
        self.label_35.setObjectName(u"label_35")
        self.label_35.setMaximumSize(QSize(60, 16777215))

        self.gridLayout_3.addWidget(self.label_35, 0, 0, 1, 1)

        self.label_34 = QLabel(self.gridLayoutWidget_3)
        self.label_34.setObjectName(u"label_34")
        self.label_34.setMaximumSize(QSize(60, 16777215))

        self.gridLayout_3.addWidget(self.label_34, 1, 0, 1, 1)


        self.verticalLayout_4.addWidget(self.grp_grid_v)

        self.check_bank_separator = QCheckBox(self.verticalLayoutWidget_2)
        self.check_bank_separator.setObjectName(u"check_bank_separator")
        self.check_bank_separator.setEnabled(False)

        self.verticalLayout_4.addWidget(self.check_bank_separator)

        self.tabWidget_2.addTab(self.tab_4, "")
        self.tab_5 = QWidget()
        self.tab_5.setObjectName(u"tab_5")
        self.verticalLayoutWidget = QWidget(self.tab_5)
        self.verticalLayoutWidget.setObjectName(u"verticalLayoutWidget")
        self.verticalLayoutWidget.setGeometry(QRect(10, 10, 401, 123))
        self.verticalLayout_5 = QVBoxLayout(self.verticalLayoutWidget)
        self.verticalLayout_5.setSpacing(6)
        self.verticalLayout_5.setContentsMargins(11, 11, 11, 11)
        self.verticalLayout_5.setObjectName(u"verticalLayout_5")
        self.verticalLayout_5.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_12 = QHBoxLayout()
        self.horizontalLayout_12.setSpacing(6)
        self.horizontalLayout_12.setObjectName(u"horizontalLayout_12")
        self.formLayout_6 = QFormLayout()
        self.formLayout_6.setSpacing(6)
        self.formLayout_6.setObjectName(u"formLayout_6")
        self.label_18 = QLabel(self.verticalLayoutWidget)
        self.label_18.setObjectName(u"label_18")

        self.formLayout_6.setWidget(0, QFormLayout.LabelRole, self.label_18)

        self.cb_cmap = QComboBox(self.verticalLayoutWidget)
        self.cb_cmap.setObjectName(u"cb_cmap")

        self.formLayout_6.setWidget(0, QFormLayout.FieldRole, self.cb_cmap)


        self.horizontalLayout_12.addLayout(self.formLayout_6)

        self.check_cmap_log = QCheckBox(self.verticalLayoutWidget)
        self.check_cmap_log.setObjectName(u"check_cmap_log")

        self.horizontalLayout_12.addWidget(self.check_cmap_log)


        self.verticalLayout_5.addLayout(self.horizontalLayout_12)

        self.horizontalLayout_15 = QHBoxLayout()
        self.horizontalLayout_15.setSpacing(6)
        self.horizontalLayout_15.setObjectName(u"horizontalLayout_15")
        self.check_smooth = QCheckBox(self.verticalLayoutWidget)
        self.check_smooth.setObjectName(u"check_smooth")

        self.horizontalLayout_15.addWidget(self.check_smooth)

        self.label_26 = QLabel(self.verticalLayoutWidget)
        self.label_26.setObjectName(u"label_26")
        self.label_26.setEnabled(False)

        self.horizontalLayout_15.addWidget(self.label_26)

        self.txt_smooth_window = QLineEdit(self.verticalLayoutWidget)
        self.txt_smooth_window.setObjectName(u"txt_smooth_window")
        self.txt_smooth_window.setEnabled(False)
        sizePolicy2 = QSizePolicy(QSizePolicy.Expanding, QSizePolicy.Fixed)
        sizePolicy2.setHorizontalStretch(0)
        sizePolicy2.setVerticalStretch(0)
        sizePolicy2.setHeightForWidth(self.txt_smooth_window.sizePolicy().hasHeightForWidth())
        self.txt_smooth_window.setSizePolicy(sizePolicy2)
        self.txt_smooth_window.setContextMenuPolicy(Qt.DefaultContextMenu)

        self.horizontalLayout_15.addWidget(self.txt_smooth_window)

        self.label_28 = QLabel(self.verticalLayoutWidget)
        self.label_28.setObjectName(u"label_28")
        self.label_28.setEnabled(False)

        self.horizontalLayout_15.addWidget(self.label_28)

        self.txt_smooth_times = QLineEdit(self.verticalLayoutWidget)
        self.txt_smooth_times.setObjectName(u"txt_smooth_times")
        self.txt_smooth_times.setEnabled(False)

        self.horizontalLayout_15.addWidget(self.txt_smooth_times)

        self.horizontalSpacer_6 = QSpacerItem(40, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)

        self.horizontalLayout_15.addItem(self.horizontalSpacer_6)


        self.verticalLayout_5.addLayout(self.horizontalLayout_15)

        self.horizontalLayout_13 = QHBoxLayout()
        self.horizontalLayout_13.setSpacing(6)
        self.horizontalLayout_13.setObjectName(u"horizontalLayout_13")
        self.horizontalLayout_13.setSizeConstraint(QLayout.SetNoConstraint)
        self.check_cmap_auto_range = QCheckBox(self.verticalLayoutWidget)
        self.check_cmap_auto_range.setObjectName(u"check_cmap_auto_range")
        self.check_cmap_auto_range.setChecked(True)

        self.horizontalLayout_13.addWidget(self.check_cmap_auto_range)

        self.horizontalLayout_14 = QHBoxLayout()
        self.horizontalLayout_14.setSpacing(6)
        self.horizontalLayout_14.setObjectName(u"horizontalLayout_14")
        self.label_19 = QLabel(self.verticalLayoutWidget)
        self.label_19.setObjectName(u"label_19")
        self.label_19.setEnabled(False)

        self.horizontalLayout_14.addWidget(self.label_19)

        self.txt_cmap_min = QLineEdit(self.verticalLayoutWidget)
        self.txt_cmap_min.setObjectName(u"txt_cmap_min")
        self.txt_cmap_min.setEnabled(False)

        self.horizontalLayout_14.addWidget(self.txt_cmap_min)

        self.label_20 = QLabel(self.verticalLayoutWidget)
        self.label_20.setObjectName(u"label_20")
        self.label_20.setEnabled(False)

        self.horizontalLayout_14.addWidget(self.label_20)

        self.txt_cmap_max = QLineEdit(self.verticalLayoutWidget)
        self.txt_cmap_max.setObjectName(u"txt_cmap_max")
        self.txt_cmap_max.setEnabled(False)

        self.horizontalLayout_14.addWidget(self.txt_cmap_max)


        self.horizontalLayout_13.addLayout(self.horizontalLayout_14)


        self.verticalLayout_5.addLayout(self.horizontalLayout_13)

        self.slider_cmap = QSlider(self.tab_5)
        self.slider_cmap.setObjectName(u"slider_cmap")
        self.slider_cmap.setEnabled(False)
        self.slider_cmap.setGeometry(QRect(10, 120, 401, 19))
        self.slider_cmap.setMaximum(100)
        self.slider_cmap.setValue(100)
        self.slider_cmap.setOrientation(Qt.Horizontal)
        self.slider_cmap.setTickPosition(QSlider.TicksBelow)
        self.slider_cmap.setTickInterval(50)
        self.label_21 = QLabel(self.tab_5)
        self.label_21.setObjectName(u"label_21")
        self.label_21.setEnabled(False)
        self.label_21.setGeometry(QRect(10, 140, 19, 12))
        self.label_22 = QLabel(self.tab_5)
        self.label_22.setObjectName(u"label_22")
        self.label_22.setEnabled(False)
        self.label_22.setGeometry(QRect(200, 140, 31, 20))
        self.label_23 = QLabel(self.tab_5)
        self.label_23.setObjectName(u"label_23")
        self.label_23.setEnabled(False)
        self.label_23.setGeometry(QRect(370, 140, 41, 20))
        self.tabWidget_2.addTab(self.tab_5, "")
        self.tab_6 = QWidget()
        self.tab_6.setObjectName(u"tab_6")
        self.lb_TF_MaskColor = QLabel(self.tab_6)
        self.lb_TF_MaskColor.setObjectName(u"lb_TF_MaskColor")
        self.lb_TF_MaskColor.setGeometry(QRect(10, 15, 101, 17))
        self.lb_TF_BGColor = QLabel(self.tab_6)
        self.lb_TF_BGColor.setObjectName(u"lb_TF_BGColor")
        self.lb_TF_BGColor.setGeometry(QRect(240, 15, 81, 17))
        self.cb_TF_MaskColor = QComboBox(self.tab_6)
        self.cb_TF_MaskColor.addItem("")
        self.cb_TF_MaskColor.addItem("")
        self.cb_TF_MaskColor.setObjectName(u"cb_TF_MaskColor")
        self.cb_TF_MaskColor.setGeometry(QRect(110, 10, 85, 27))
        self.cb_TF_BGColor = QComboBox(self.tab_6)
        self.cb_TF_BGColor.addItem("")
        self.cb_TF_BGColor.addItem("")
        self.cb_TF_BGColor.setObjectName(u"cb_TF_BGColor")
        self.cb_TF_BGColor.setGeometry(QRect(320, 10, 85, 27))
        self.ch_TF_TopSideTicks = QCheckBox(self.tab_6)
        self.ch_TF_TopSideTicks.setObjectName(u"ch_TF_TopSideTicks")
        self.ch_TF_TopSideTicks.setGeometry(QRect(160, 60, 61, 22))
        self.ch_TF_RightSideTicks = QCheckBox(self.tab_6)
        self.ch_TF_RightSideTicks.setObjectName(u"ch_TF_RightSideTicks")
        self.ch_TF_RightSideTicks.setGeometry(QRect(160, 80, 61, 22))
        self.lb_TF_AddTicks = QLabel(self.tab_6)
        self.lb_TF_AddTicks.setObjectName(u"lb_TF_AddTicks")
        self.lb_TF_AddTicks.setGeometry(QRect(10, 63, 101, 17))
        self.lb_TF_TicksColor = QLabel(self.tab_6)
        self.lb_TF_TicksColor.setObjectName(u"lb_TF_TicksColor")
        self.lb_TF_TicksColor.setGeometry(QRect(240, 63, 81, 17))
        self.cb_TF_TicksColor = QComboBox(self.tab_6)
        self.cb_TF_TicksColor.addItem("")
        self.cb_TF_TicksColor.addItem("")
        self.cb_TF_TicksColor.setObjectName(u"cb_TF_TicksColor")
        self.cb_TF_TicksColor.setGeometry(QRect(320, 60, 85, 27))
        self.lb_TF_MajorTicks = QLabel(self.tab_6)
        self.lb_TF_MajorTicks.setObjectName(u"lb_TF_MajorTicks")
        self.lb_TF_MajorTicks.setGeometry(QRect(30, 120, 91, 17))
        self.lb_TF_MajorTicks_L = QLabel(self.tab_6)
        self.lb_TF_MajorTicks_L.setObjectName(u"lb_TF_MajorTicks_L")
        self.lb_TF_MajorTicks_L.setGeometry(QRect(140, 120, 68, 17))
        self.lb_TF_MajorTicks_W = QLabel(self.tab_6)
        self.lb_TF_MajorTicks_W.setObjectName(u"lb_TF_MajorTicks_W")
        self.lb_TF_MajorTicks_W.setGeometry(QRect(280, 120, 68, 17))
        self.ch_TF_MinorTicks = QCheckBox(self.tab_6)
        self.ch_TF_MinorTicks.setObjectName(u"ch_TF_MinorTicks")
        self.ch_TF_MinorTicks.setGeometry(QRect(10, 150, 121, 22))
        self.txt_TF_MajorTicks_L = QLineEdit(self.tab_6)
        self.txt_TF_MajorTicks_L.setObjectName(u"txt_TF_MajorTicks_L")
        self.txt_TF_MajorTicks_L.setGeometry(QRect(210, 115, 51, 27))
        self.txt_TF_MajorTicks_W = QLineEdit(self.tab_6)
        self.txt_TF_MajorTicks_W.setObjectName(u"txt_TF_MajorTicks_W")
        self.txt_TF_MajorTicks_W.setGeometry(QRect(340, 115, 51, 27))
        self.txt_TF_MinorTicks_L = QLineEdit(self.tab_6)
        self.txt_TF_MinorTicks_L.setObjectName(u"txt_TF_MinorTicks_L")
        self.txt_TF_MinorTicks_L.setEnabled(False)
        self.txt_TF_MinorTicks_L.setGeometry(QRect(210, 150, 51, 27))
        self.txt_TF_MinorTicks_W = QLineEdit(self.tab_6)
        self.txt_TF_MinorTicks_W.setObjectName(u"txt_TF_MinorTicks_W")
        self.txt_TF_MinorTicks_W.setEnabled(False)
        self.txt_TF_MinorTicks_W.setGeometry(QRect(340, 150, 51, 27))
        self.txt_TF_FrameLine_W = QLineEdit(self.tab_6)
        self.txt_TF_FrameLine_W.setObjectName(u"txt_TF_FrameLine_W")
        self.txt_TF_FrameLine_W.setGeometry(QRect(210, 190, 51, 27))
        self.lb_TF_MinorTicks_L = QLabel(self.tab_6)
        self.lb_TF_MinorTicks_L.setObjectName(u"lb_TF_MinorTicks_L")
        self.lb_TF_MinorTicks_L.setGeometry(QRect(140, 152, 68, 17))
        self.lb_TF_MinorTicks_W = QLabel(self.tab_6)
        self.lb_TF_MinorTicks_W.setObjectName(u"lb_TF_MinorTicks_W")
        self.lb_TF_MinorTicks_W.setGeometry(QRect(280, 152, 68, 17))
        self.lb_TF_FrameLine_W = QLabel(self.tab_6)
        self.lb_TF_FrameLine_W.setObjectName(u"lb_TF_FrameLine_W")
        self.lb_TF_FrameLine_W.setGeometry(QRect(60, 192, 151, 17))
        self.line = QFrame(self.tab_6)
        self.line.setObjectName(u"line")
        self.line.setGeometry(QRect(20, 40, 381, 20))
        self.line.setFrameShape(QFrame.HLine)
        self.line.setFrameShadow(QFrame.Sunken)
        self.ch_TF_BottomSideTicks = QCheckBox(self.tab_6)
        self.ch_TF_BottomSideTicks.setObjectName(u"ch_TF_BottomSideTicks")
        self.ch_TF_BottomSideTicks.setGeometry(QRect(80, 60, 71, 22))
        self.ch_TF_BottomSideTicks.setChecked(True)
        self.ch_TF_BottomSideTicks.setTristate(False)
        self.ch_TF_LeftSideTicks = QCheckBox(self.tab_6)
        self.ch_TF_LeftSideTicks.setObjectName(u"ch_TF_LeftSideTicks")
        self.ch_TF_LeftSideTicks.setGeometry(QRect(80, 80, 61, 22))
        self.ch_TF_LeftSideTicks.setChecked(True)
        self.tabWidget_2.addTab(self.tab_6, "")
        self.tab_7 = QWidget()
        self.tab_7.setObjectName(u"tab_7")
        self.gridLayoutWidget_10 = QWidget(self.tab_7)
        self.gridLayoutWidget_10.setObjectName(u"gridLayoutWidget_10")
        self.gridLayoutWidget_10.setGeometry(QRect(10, 10, 331, 231))
        self.gridLayout_10 = QGridLayout(self.gridLayoutWidget_10)
        self.gridLayout_10.setSpacing(6)
        self.gridLayout_10.setContentsMargins(11, 11, 11, 11)
        self.gridLayout_10.setObjectName(u"gridLayout_10")
        self.gridLayout_10.setSizeConstraint(QLayout.SetMinimumSize)
        self.gridLayout_10.setContentsMargins(0, 0, 0, 0)
        self.txt_fs_y = QLineEdit(self.gridLayoutWidget_10)
        self.txt_fs_y.setObjectName(u"txt_fs_y")
        self.txt_fs_y.setMaximumSize(QSize(40, 22))
        self.txt_fs_y.setMaxLength(2)

        self.gridLayout_10.addWidget(self.txt_fs_y, 4, 2, 1, 1)

        self.label_50 = QLabel(self.gridLayoutWidget_10)
        self.label_50.setObjectName(u"label_50")
        self.label_50.setMaximumSize(QSize(16777215, 20))

        self.gridLayout_10.addWidget(self.label_50, 0, 4, 1, 1)

        self.cb_ft_xticks = QComboBox(self.gridLayoutWidget_10)
        self.cb_ft_xticks.setObjectName(u"cb_ft_xticks")
        self.cb_ft_xticks.setMaximumSize(QSize(16777215, 22))

        self.gridLayout_10.addWidget(self.cb_ft_xticks, 5, 4, 1, 1)

        self.label_48 = QLabel(self.gridLayoutWidget_10)
        self.label_48.setObjectName(u"label_48")
        self.label_48.setMaximumSize(QSize(16777215, 22))

        self.gridLayout_10.addWidget(self.label_48, 1, 0, 1, 1)

        self.txt_fs_title = QLineEdit(self.gridLayoutWidget_10)
        self.txt_fs_title.setObjectName(u"txt_fs_title")
        sizePolicy1.setHeightForWidth(self.txt_fs_title.sizePolicy().hasHeightForWidth())
        self.txt_fs_title.setSizePolicy(sizePolicy1)
        self.txt_fs_title.setMaximumSize(QSize(40, 22))
        self.txt_fs_title.setMaxLength(2)

        self.gridLayout_10.addWidget(self.txt_fs_title, 1, 2, 1, 1)

        self.cb_ft_x = QComboBox(self.gridLayoutWidget_10)
        self.cb_ft_x.setObjectName(u"cb_ft_x")
        self.cb_ft_x.setMaximumSize(QSize(16777215, 22))

        self.gridLayout_10.addWidget(self.cb_ft_x, 3, 4, 1, 1)

        self.txt_fs_x = QLineEdit(self.gridLayoutWidget_10)
        self.txt_fs_x.setObjectName(u"txt_fs_x")
        self.txt_fs_x.setMaximumSize(QSize(40, 22))
        self.txt_fs_x.setMaxLength(2)

        self.gridLayout_10.addWidget(self.txt_fs_x, 3, 2, 1, 1)

        self.txt_fs_comment = QLineEdit(self.gridLayoutWidget_10)
        self.txt_fs_comment.setObjectName(u"txt_fs_comment")
        self.txt_fs_comment.setMaximumSize(QSize(40, 22))
        self.txt_fs_comment.setMaxLength(2)

        self.gridLayout_10.addWidget(self.txt_fs_comment, 2, 2, 1, 1)

        self.cb_ft_title = QComboBox(self.gridLayoutWidget_10)
        self.cb_ft_title.setObjectName(u"cb_ft_title")
        self.cb_ft_title.setMaximumSize(QSize(16777215, 22))

        self.gridLayout_10.addWidget(self.cb_ft_title, 1, 4, 1, 1)

        self.label_49 = QLabel(self.gridLayoutWidget_10)
        self.label_49.setObjectName(u"label_49")
        self.label_49.setMaximumSize(QSize(16777215, 20))

        self.gridLayout_10.addWidget(self.label_49, 0, 2, 1, 1)

        self.horizontalSpacer_10 = QSpacerItem(10, 20, QSizePolicy.Fixed, QSizePolicy.Minimum)

        self.gridLayout_10.addItem(self.horizontalSpacer_10, 0, 1, 1, 1)

        self.cb_ft_comment = QComboBox(self.gridLayoutWidget_10)
        self.cb_ft_comment.setObjectName(u"cb_ft_comment")
        self.cb_ft_comment.setMaximumSize(QSize(16777215, 22))

        self.gridLayout_10.addWidget(self.cb_ft_comment, 2, 4, 1, 1)

        self.label_17 = QLabel(self.gridLayoutWidget_10)
        self.label_17.setObjectName(u"label_17")
        self.label_17.setMaximumSize(QSize(16777215, 22))

        self.gridLayout_10.addWidget(self.label_17, 2, 0, 1, 1)

        self.cb_ft_yticks = QComboBox(self.gridLayoutWidget_10)
        self.cb_ft_yticks.setObjectName(u"cb_ft_yticks")
        self.cb_ft_yticks.setMaximumSize(QSize(16777215, 22))

        self.gridLayout_10.addWidget(self.cb_ft_yticks, 6, 4, 1, 1)

        self.horizontalSpacer_9 = QSpacerItem(140, 20, QSizePolicy.Fixed, QSizePolicy.Minimum)

        self.gridLayout_10.addItem(self.horizontalSpacer_9, 0, 0, 1, 1)

        self.cb_ft_y = QComboBox(self.gridLayoutWidget_10)
        self.cb_ft_y.setObjectName(u"cb_ft_y")
        self.cb_ft_y.setMaximumSize(QSize(16777215, 22))

        self.gridLayout_10.addWidget(self.cb_ft_y, 4, 4, 1, 1)

        self.txt_fs_xticks = QLineEdit(self.gridLayoutWidget_10)
        self.txt_fs_xticks.setObjectName(u"txt_fs_xticks")
        self.txt_fs_xticks.setMaximumSize(QSize(40, 22))
        self.txt_fs_xticks.setMaxLength(2)

        self.gridLayout_10.addWidget(self.txt_fs_xticks, 5, 2, 1, 1)

        self.txt_fs_yticks = QLineEdit(self.gridLayoutWidget_10)
        self.txt_fs_yticks.setObjectName(u"txt_fs_yticks")
        self.txt_fs_yticks.setMaximumSize(QSize(40, 22))
        self.txt_fs_yticks.setMaxLength(2)

        self.gridLayout_10.addWidget(self.txt_fs_yticks, 6, 2, 1, 1)

        self.horizontalSpacer_11 = QSpacerItem(10, 20, QSizePolicy.Fixed, QSizePolicy.Minimum)

        self.gridLayout_10.addItem(self.horizontalSpacer_11, 0, 3, 1, 1)

        self.label_37 = QLabel(self.gridLayoutWidget_10)
        self.label_37.setObjectName(u"label_37")
        self.label_37.setMaximumSize(QSize(16777215, 22))

        self.gridLayout_10.addWidget(self.label_37, 3, 0, 1, 1)

        self.label_38 = QLabel(self.gridLayoutWidget_10)
        self.label_38.setObjectName(u"label_38")
        self.label_38.setMaximumSize(QSize(16777215, 22))

        self.gridLayout_10.addWidget(self.label_38, 4, 0, 1, 1)

        self.label_39 = QLabel(self.gridLayoutWidget_10)
        self.label_39.setObjectName(u"label_39")
        self.label_39.setMaximumSize(QSize(16777215, 22))

        self.gridLayout_10.addWidget(self.label_39, 5, 0, 1, 1)

        self.label_40 = QLabel(self.gridLayoutWidget_10)
        self.label_40.setObjectName(u"label_40")
        self.label_40.setMaximumSize(QSize(16777215, 22))

        self.gridLayout_10.addWidget(self.label_40, 6, 0, 1, 1)

        self.label_41 = QLabel(self.gridLayoutWidget_10)
        self.label_41.setObjectName(u"label_41")
        self.label_41.setMaximumSize(QSize(16777215, 22))

        self.gridLayout_10.addWidget(self.label_41, 7, 0, 1, 1)

        self.txt_fs_cbticks = QLineEdit(self.gridLayoutWidget_10)
        self.txt_fs_cbticks.setObjectName(u"txt_fs_cbticks")
        self.txt_fs_cbticks.setMaximumSize(QSize(40, 22))
        self.txt_fs_cbticks.setMaxLength(2)

        self.gridLayout_10.addWidget(self.txt_fs_cbticks, 7, 2, 1, 1)

        self.cb_ft_cbticks = QComboBox(self.gridLayoutWidget_10)
        self.cb_ft_cbticks.setObjectName(u"cb_ft_cbticks")
        self.cb_ft_cbticks.setMaximumSize(QSize(16777215, 22))

        self.gridLayout_10.addWidget(self.cb_ft_cbticks, 7, 4, 1, 1)

        self.tabWidget_2.addTab(self.tab_7, "")
        self.btn_close = QPushButton(DlgViewPrms)
        self.btn_close.setObjectName(u"btn_close")
        self.btn_close.setGeometry(QRect(270, 520, 51, 31))
        self.btn_apply = QPushButton(DlgViewPrms)
        self.btn_apply.setObjectName(u"btn_apply")
        self.btn_apply.setGeometry(QRect(330, 510, 101, 51))
        self.btn_backToInitial = QPushButton(DlgViewPrms)
        self.btn_backToInitial.setObjectName(u"btn_backToInitial")
        self.btn_backToInitial.setGeometry(QRect(160, 510, 61, 26))
        self.btn_backToDefault = QPushButton(DlgViewPrms)
        self.btn_backToDefault.setObjectName(u"btn_backToDefault")
        self.btn_backToDefault.setGeometry(QRect(90, 510, 61, 26))
        self.btn_saveAsDefault = QPushButton(DlgViewPrms)
        self.btn_saveAsDefault.setObjectName(u"btn_saveAsDefault")
        self.btn_saveAsDefault.setGeometry(QRect(90, 560, 61, 26))
        self.label_29 = QLabel(DlgViewPrms)
        self.label_29.setObjectName(u"label_29")
        self.label_29.setGeometry(QRect(20, 510, 68, 26))
        self.label_30 = QLabel(DlgViewPrms)
        self.label_30.setObjectName(u"label_30")
        self.label_30.setGeometry(QRect(20, 540, 121, 26))
        self.btn_saveAsDefault_local = QPushButton(DlgViewPrms)
        self.btn_saveAsDefault_local.setObjectName(u"btn_saveAsDefault_local")
        self.btn_saveAsDefault_local.setGeometry(QRect(160, 560, 61, 26))
        QWidget.setTabOrder(self.tabWidget, self.txt_x_label)
        QWidget.setTabOrder(self.txt_x_label, self.txt_x_unit)
        QWidget.setTabOrder(self.txt_x_unit, self.check_x_log)
        QWidget.setTabOrder(self.check_x_log, self.check_x_inv)
        QWidget.setTabOrder(self.check_x_inv, self.check_x_auto_range)
        QWidget.setTabOrder(self.check_x_auto_range, self.txt_x_min)
        QWidget.setTabOrder(self.txt_x_min, self.txt_x_max)
        QWidget.setTabOrder(self.txt_x_max, self.check_x_auto_tick)
        QWidget.setTabOrder(self.check_x_auto_tick, self.combo_x_format)
        QWidget.setTabOrder(self.combo_x_format, self.spin_x_prec)
        QWidget.setTabOrder(self.spin_x_prec, self.check_y_log)
        QWidget.setTabOrder(self.check_y_log, self.check_y_inv)
        QWidget.setTabOrder(self.check_y_inv, self.check_y_auto_range)
        QWidget.setTabOrder(self.check_y_auto_range, self.txt_y_label)
        QWidget.setTabOrder(self.txt_y_label, self.txt_y_unit)
        QWidget.setTabOrder(self.txt_y_unit, self.txt_y_min)
        QWidget.setTabOrder(self.txt_y_min, self.txt_y_max)
        QWidget.setTabOrder(self.txt_y_max, self.check_y_auto_tick)
        QWidget.setTabOrder(self.check_y_auto_tick, self.combo_y_format)
        QWidget.setTabOrder(self.combo_y_format, self.spin_y_prec)
        QWidget.setTabOrder(self.spin_y_prec, self.btn_apply)
        QWidget.setTabOrder(self.btn_apply, self.btn_close)
        QWidget.setTabOrder(self.btn_close, self.tabWidget_2)
        QWidget.setTabOrder(self.tabWidget_2, self.txt_title)
        QWidget.setTabOrder(self.txt_title, self.txt_comment)
        QWidget.setTabOrder(self.txt_comment, self.txt_width)
        QWidget.setTabOrder(self.txt_width, self.txt_height)
        QWidget.setTabOrder(self.txt_height, self.btn_winsize)
        QWidget.setTabOrder(self.btn_winsize, self.check_auto_update)
        QWidget.setTabOrder(self.check_auto_update, self.check_trans)
        QWidget.setTabOrder(self.check_trans, self.rb_isAveSlice)
        QWidget.setTabOrder(self.rb_isAveSlice, self.rb_isSumSlice)
        QWidget.setTabOrder(self.rb_isSumSlice, self.grp_grid_h)
        QWidget.setTabOrder(self.grp_grid_h, self.cb_grid_color_h)
        QWidget.setTabOrder(self.cb_grid_color_h, self.txt_grid_width_h)
        QWidget.setTabOrder(self.txt_grid_width_h, self.cb_grid_style_h)
        QWidget.setTabOrder(self.cb_grid_style_h, self.txt_h_interval)
        QWidget.setTabOrder(self.txt_h_interval, self.grp_grid_v)
        QWidget.setTabOrder(self.grp_grid_v, self.cb_grid_color_v)
        QWidget.setTabOrder(self.cb_grid_color_v, self.txt_grid_width_v)
        QWidget.setTabOrder(self.txt_grid_width_v, self.cb_grid_style_v)
        QWidget.setTabOrder(self.cb_grid_style_v, self.txt_v_interval)
        QWidget.setTabOrder(self.txt_v_interval, self.check_bank_separator)
        QWidget.setTabOrder(self.check_bank_separator, self.cb_cmap)
        QWidget.setTabOrder(self.cb_cmap, self.check_cmap_log)
        QWidget.setTabOrder(self.check_cmap_log, self.check_smooth)
        QWidget.setTabOrder(self.check_smooth, self.txt_smooth_window)
        QWidget.setTabOrder(self.txt_smooth_window, self.txt_smooth_times)
        QWidget.setTabOrder(self.txt_smooth_times, self.check_cmap_auto_range)
        QWidget.setTabOrder(self.check_cmap_auto_range, self.txt_cmap_min)
        QWidget.setTabOrder(self.txt_cmap_min, self.txt_cmap_max)
        QWidget.setTabOrder(self.txt_cmap_max, self.slider_cmap)
        QWidget.setTabOrder(self.slider_cmap, self.cb_TF_MaskColor)
        QWidget.setTabOrder(self.cb_TF_MaskColor, self.cb_TF_BGColor)
        QWidget.setTabOrder(self.cb_TF_BGColor, self.ch_TF_BottomSideTicks)
        QWidget.setTabOrder(self.ch_TF_BottomSideTicks, self.ch_TF_LeftSideTicks)
        QWidget.setTabOrder(self.ch_TF_LeftSideTicks, self.ch_TF_TopSideTicks)
        QWidget.setTabOrder(self.ch_TF_TopSideTicks, self.ch_TF_RightSideTicks)
        QWidget.setTabOrder(self.ch_TF_RightSideTicks, self.cb_TF_TicksColor)
        QWidget.setTabOrder(self.cb_TF_TicksColor, self.ch_TF_MinorTicks)
        QWidget.setTabOrder(self.ch_TF_MinorTicks, self.txt_TF_MajorTicks_L)
        QWidget.setTabOrder(self.txt_TF_MajorTicks_L, self.txt_TF_MajorTicks_W)
        QWidget.setTabOrder(self.txt_TF_MajorTicks_W, self.txt_TF_MinorTicks_L)
        QWidget.setTabOrder(self.txt_TF_MinorTicks_L, self.txt_TF_MinorTicks_W)
        QWidget.setTabOrder(self.txt_TF_MinorTicks_W, self.txt_TF_FrameLine_W)
        QWidget.setTabOrder(self.txt_TF_FrameLine_W, self.txt_fs_title)
        QWidget.setTabOrder(self.txt_fs_title, self.cb_ft_title)
        QWidget.setTabOrder(self.cb_ft_title, self.txt_fs_comment)
        QWidget.setTabOrder(self.txt_fs_comment, self.cb_ft_comment)
        QWidget.setTabOrder(self.cb_ft_comment, self.txt_fs_x)
        QWidget.setTabOrder(self.txt_fs_x, self.cb_ft_x)
        QWidget.setTabOrder(self.cb_ft_x, self.txt_fs_y)
        QWidget.setTabOrder(self.txt_fs_y, self.cb_ft_y)
        QWidget.setTabOrder(self.cb_ft_y, self.txt_fs_xticks)
        QWidget.setTabOrder(self.txt_fs_xticks, self.cb_ft_xticks)
        QWidget.setTabOrder(self.cb_ft_xticks, self.txt_fs_yticks)
        QWidget.setTabOrder(self.txt_fs_yticks, self.cb_ft_yticks)
        QWidget.setTabOrder(self.cb_ft_yticks, self.txt_fs_cbticks)
        QWidget.setTabOrder(self.txt_fs_cbticks, self.cb_ft_cbticks)
        QWidget.setTabOrder(self.cb_ft_cbticks, self.btn_backToDefault)
        QWidget.setTabOrder(self.btn_backToDefault, self.btn_backToInitial)
        QWidget.setTabOrder(self.btn_backToInitial, self.btn_saveAsDefault)

        self.retranslateUi(DlgViewPrms)
        self.check_y_auto_range.toggled.connect(self.txt_y_min.setDisabled)
        self.check_y_auto_range.toggled.connect(self.txt_y_max.setDisabled)
        self.check_y_auto_range.toggled.connect(self.label_4.setDisabled)
        self.check_y_auto_range.toggled.connect(self.label_5.setDisabled)
        self.check_y_auto_tick.toggled.connect(self.label_6.setDisabled)
        self.check_y_auto_tick.toggled.connect(self.label_7.setDisabled)
        self.check_y_auto_tick.toggled.connect(self.spin_y_prec.setDisabled)
        self.check_x_auto_range.toggled.connect(self.txt_x_min.setDisabled)
        self.check_x_auto_range.toggled.connect(self.label_12.setDisabled)
        self.check_x_auto_range.toggled.connect(self.label_13.setDisabled)
        self.check_x_auto_range.toggled.connect(self.txt_x_max.setDisabled)
        self.check_x_auto_tick.toggled.connect(self.label_10.setDisabled)
        self.check_x_auto_tick.toggled.connect(self.spin_x_prec.setDisabled)
        self.check_x_auto_tick.toggled.connect(self.label_9.setDisabled)
        self.check_cmap_auto_range.toggled.connect(self.label_19.setDisabled)
        self.check_cmap_auto_range.toggled.connect(self.txt_cmap_min.setDisabled)
        self.check_cmap_auto_range.toggled.connect(self.label_20.setDisabled)
        self.check_cmap_auto_range.toggled.connect(self.txt_cmap_max.setDisabled)
        self.check_cmap_auto_range.toggled.connect(self.slider_cmap.setDisabled)
        self.check_cmap_auto_range.toggled.connect(self.label_21.setDisabled)
        self.check_cmap_auto_range.toggled.connect(self.label_22.setDisabled)
        self.check_cmap_auto_range.toggled.connect(self.label_23.setDisabled)
        self.check_x_auto_tick.toggled.connect(self.combo_x_format.setDisabled)
        self.check_y_auto_tick.toggled.connect(self.combo_y_format.setDisabled)
        self.check_smooth.toggled.connect(self.txt_smooth_window.setEnabled)
        self.check_smooth.toggled.connect(self.label_26.setEnabled)
        self.check_smooth.toggled.connect(self.label_28.setEnabled)
        self.check_smooth.toggled.connect(self.txt_smooth_times.setEnabled)
        self.ch_TF_MinorTicks.toggled.connect(self.txt_TF_MinorTicks_L.setEnabled)
        self.ch_TF_MinorTicks.toggled.connect(self.txt_TF_MinorTicks_W.setEnabled)

        self.tabWidget.setCurrentIndex(0)
        self.combo_x_format.setCurrentIndex(-1)
        self.combo_y_format.setCurrentIndex(-1)
        self.tabWidget_2.setCurrentIndex(0)


        QMetaObject.connectSlotsByName(DlgViewPrms)
    # setupUi

    def retranslateUi(self, DlgViewPrms):
        DlgViewPrms.setWindowTitle(QCoreApplication.translate("DlgViewPrms", u"Set View Parameters", None))
        self.check_x_auto_range.setText(QCoreApplication.translate("DlgViewPrms", u"Auto Scale", None))
        self.label_12.setText(QCoreApplication.translate("DlgViewPrms", u"Range", None))
        self.label_13.setText(QCoreApplication.translate("DlgViewPrms", u"-", None))
        self.check_x_log.setText(QCoreApplication.translate("DlgViewPrms", u"Log Scale", None))
        self.check_x_inv.setText(QCoreApplication.translate("DlgViewPrms", u"Inversion", None))
        self.check_x_auto_tick.setText(QCoreApplication.translate("DlgViewPrms", u"Auto Format", None))
        self.label_9.setText(QCoreApplication.translate("DlgViewPrms", u"Format", None))
        self.label_10.setText(QCoreApplication.translate("DlgViewPrms", u"Precision", None))
        self.label_8.setText(QCoreApplication.translate("DlgViewPrms", u"Ticks Label Format", None))
        self.txt_x_label.setText(QCoreApplication.translate("DlgViewPrms", u"X", None))
        self.label_14.setText(QCoreApplication.translate("DlgViewPrms", u"Label", None))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), QCoreApplication.translate("DlgViewPrms", u"X Scale", None))
        self.check_y_auto_range.setText(QCoreApplication.translate("DlgViewPrms", u"Auto Scale", None))
        self.label_4.setText(QCoreApplication.translate("DlgViewPrms", u"Range", None))
        self.label_5.setText(QCoreApplication.translate("DlgViewPrms", u"-", None))
        self.check_y_log.setText(QCoreApplication.translate("DlgViewPrms", u"Log Scale", None))
        self.check_y_inv.setText(QCoreApplication.translate("DlgViewPrms", u"Inversion", None))
        self.check_y_auto_tick.setText(QCoreApplication.translate("DlgViewPrms", u"Auto Format", None))
        self.label_6.setText(QCoreApplication.translate("DlgViewPrms", u"Format", None))
        self.label_7.setText(QCoreApplication.translate("DlgViewPrms", u"Precision", None))
        self.label_11.setText(QCoreApplication.translate("DlgViewPrms", u"Ticks Label Format", None))
        self.txt_y_label.setText(QCoreApplication.translate("DlgViewPrms", u"Y", None))
        self.label_3.setText(QCoreApplication.translate("DlgViewPrms", u"Label", None))
        self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), QCoreApplication.translate("DlgViewPrms", u"Y Scale", None))
        self.label.setText(QCoreApplication.translate("DlgViewPrms", u"Title", None))
        self.label_2.setText(QCoreApplication.translate("DlgViewPrms", u"Comment", None))
        self.label_24.setText(QCoreApplication.translate("DlgViewPrms", u"Main plot width", None))
        self.label_25.setText(QCoreApplication.translate("DlgViewPrms", u"height", None))
        self.btn_winsize.setText(QCoreApplication.translate("DlgViewPrms", u"Current", None))
        self.check_auto_update.setText(QCoreApplication.translate("DlgViewPrms", u"Auto Update", None))
        self.check_trans.setText(QCoreApplication.translate("DlgViewPrms", u"Transposition of the Axes", None))
        self.label_27.setText(QCoreApplication.translate("DlgViewPrms", u"      Slice Mode :", None))
        self.rb_isAveSlice.setText(QCoreApplication.translate("DlgViewPrms", u"Average", None))
        self.rb_isSumSlice.setText(QCoreApplication.translate("DlgViewPrms", u"Summation", None))
        self.tabWidget_2.setTabText(self.tabWidget_2.indexOf(self.tab_3), QCoreApplication.translate("DlgViewPrms", u"General", None))
        self.grp_grid_h.setTitle(QCoreApplication.translate("DlgViewPrms", u"Horizontal", None))
        self.label_31.setText(QCoreApplication.translate("DlgViewPrms", u"Color", None))
        self.txt_grid_width_h.setText(QCoreApplication.translate("DlgViewPrms", u"0.5", None))
        self.label_32.setText(QCoreApplication.translate("DlgViewPrms", u"Style", None))
        self.label_15.setText(QCoreApplication.translate("DlgViewPrms", u"Interval", None))
        self.label_33.setText(QCoreApplication.translate("DlgViewPrms", u"Width", None))
        self.grp_grid_v.setTitle(QCoreApplication.translate("DlgViewPrms", u"Vertical", None))
        self.label_36.setText(QCoreApplication.translate("DlgViewPrms", u"Width", None))
        self.txt_grid_width_v.setText(QCoreApplication.translate("DlgViewPrms", u"0.5", None))
        self.label_16.setText(QCoreApplication.translate("DlgViewPrms", u"Interval", None))
        self.label_35.setText(QCoreApplication.translate("DlgViewPrms", u"Color", None))
        self.label_34.setText(QCoreApplication.translate("DlgViewPrms", u"Style", None))
        self.check_bank_separator.setText(QCoreApplication.translate("DlgViewPrms", u"Bank Separator", None))
        self.tabWidget_2.setTabText(self.tabWidget_2.indexOf(self.tab_4), QCoreApplication.translate("DlgViewPrms", u"Grid", None))
        self.label_18.setText(QCoreApplication.translate("DlgViewPrms", u"Color Map", None))
        self.check_cmap_log.setText(QCoreApplication.translate("DlgViewPrms", u"Log Scale", None))
        self.check_smooth.setText(QCoreApplication.translate("DlgViewPrms", u"Smoothing", None))
        self.label_26.setText(QCoreApplication.translate("DlgViewPrms", u"Window", None))
        self.txt_smooth_window.setText(QCoreApplication.translate("DlgViewPrms", u"1", None))
        self.label_28.setText(QCoreApplication.translate("DlgViewPrms", u"Times", None))
        self.txt_smooth_times.setText(QCoreApplication.translate("DlgViewPrms", u"1", None))
        self.check_cmap_auto_range.setText(QCoreApplication.translate("DlgViewPrms", u"Auto Scale", None))
        self.label_19.setText(QCoreApplication.translate("DlgViewPrms", u"Range", None))
        self.label_20.setText(QCoreApplication.translate("DlgViewPrms", u"-", None))
        self.label_21.setText(QCoreApplication.translate("DlgViewPrms", u"0%", None))
        self.label_22.setText(QCoreApplication.translate("DlgViewPrms", u"50%", None))
        self.label_23.setText(QCoreApplication.translate("DlgViewPrms", u"100%", None))
        self.tabWidget_2.setTabText(self.tabWidget_2.indexOf(self.tab_5), QCoreApplication.translate("DlgViewPrms", u"Color Map", None))
        self.lb_TF_MaskColor.setText(QCoreApplication.translate("DlgViewPrms", u"Mask Color :", None))
        self.lb_TF_BGColor.setText(QCoreApplication.translate("DlgViewPrms", u"BG Color :", None))
        self.cb_TF_MaskColor.setItemText(0, QCoreApplication.translate("DlgViewPrms", u"Black", None))
        self.cb_TF_MaskColor.setItemText(1, QCoreApplication.translate("DlgViewPrms", u"White", None))

        self.cb_TF_BGColor.setItemText(0, QCoreApplication.translate("DlgViewPrms", u"Black", None))
        self.cb_TF_BGColor.setItemText(1, QCoreApplication.translate("DlgViewPrms", u"White", None))

        self.ch_TF_TopSideTicks.setText(QCoreApplication.translate("DlgViewPrms", u"Top", None))
        self.ch_TF_RightSideTicks.setText(QCoreApplication.translate("DlgViewPrms", u"Right", None))
        self.lb_TF_AddTicks.setText(QCoreApplication.translate("DlgViewPrms", u"Add Ticks : ", None))
        self.lb_TF_TicksColor.setText(QCoreApplication.translate("DlgViewPrms", u"Ticks Color :", None))
        self.cb_TF_TicksColor.setItemText(0, QCoreApplication.translate("DlgViewPrms", u"Black", None))
        self.cb_TF_TicksColor.setItemText(1, QCoreApplication.translate("DlgViewPrms", u"White", None))

        self.lb_TF_MajorTicks.setText(QCoreApplication.translate("DlgViewPrms", u"Major Ticks", None))
        self.lb_TF_MajorTicks_L.setText(QCoreApplication.translate("DlgViewPrms", u"Length :", None))
        self.lb_TF_MajorTicks_W.setText(QCoreApplication.translate("DlgViewPrms", u"Width :", None))
        self.ch_TF_MinorTicks.setText(QCoreApplication.translate("DlgViewPrms", u"Minor Ticks", None))
        self.lb_TF_MinorTicks_L.setText(QCoreApplication.translate("DlgViewPrms", u"Length :", None))
        self.lb_TF_MinorTicks_W.setText(QCoreApplication.translate("DlgViewPrms", u"Width :", None))
        self.lb_TF_FrameLine_W.setText(QCoreApplication.translate("DlgViewPrms", u"Frame Line Width :", None))
        self.ch_TF_BottomSideTicks.setText(QCoreApplication.translate("DlgViewPrms", u"Bottom", None))
        self.ch_TF_LeftSideTicks.setText(QCoreApplication.translate("DlgViewPrms", u"Left", None))
        self.tabWidget_2.setTabText(self.tabWidget_2.indexOf(self.tab_6), QCoreApplication.translate("DlgViewPrms", u"Ticks-Frame", None))
        self.txt_fs_y.setText(QCoreApplication.translate("DlgViewPrms", u"9", None))
        self.label_50.setText(QCoreApplication.translate("DlgViewPrms", u"Type", None))
        self.label_48.setText(QCoreApplication.translate("DlgViewPrms", u"Title", None))
        self.txt_fs_title.setText(QCoreApplication.translate("DlgViewPrms", u"10", None))
        self.txt_fs_x.setText(QCoreApplication.translate("DlgViewPrms", u"9", None))
        self.txt_fs_comment.setText(QCoreApplication.translate("DlgViewPrms", u"8", None))
        self.label_49.setText(QCoreApplication.translate("DlgViewPrms", u"Size", None))
        self.label_17.setText(QCoreApplication.translate("DlgViewPrms", u"Comment", None))
        self.txt_fs_xticks.setText(QCoreApplication.translate("DlgViewPrms", u"8", None))
        self.txt_fs_yticks.setText(QCoreApplication.translate("DlgViewPrms", u"8", None))
        self.label_37.setText(QCoreApplication.translate("DlgViewPrms", u"X Label", None))
        self.label_38.setText(QCoreApplication.translate("DlgViewPrms", u"Y Label", None))
        self.label_39.setText(QCoreApplication.translate("DlgViewPrms", u"X Ticks Label", None))
        self.label_40.setText(QCoreApplication.translate("DlgViewPrms", u"Y Ticks Label", None))
        self.label_41.setText(QCoreApplication.translate("DlgViewPrms", u"Colorbar Ticks Label", None))
        self.txt_fs_cbticks.setText(QCoreApplication.translate("DlgViewPrms", u"8", None))
        self.tabWidget_2.setTabText(self.tabWidget_2.indexOf(self.tab_7), QCoreApplication.translate("DlgViewPrms", u"Font", None))
        self.btn_close.setText(QCoreApplication.translate("DlgViewPrms", u"Close", None))
        self.btn_apply.setText(QCoreApplication.translate("DlgViewPrms", u"Apply", None))
        self.btn_backToInitial.setText(QCoreApplication.translate("DlgViewPrms", u"Initial", None))
        self.btn_backToDefault.setText(QCoreApplication.translate("DlgViewPrms", u"Default", None))
        self.btn_saveAsDefault.setText(QCoreApplication.translate("DlgViewPrms", u"System", None))
        self.label_29.setText(QCoreApplication.translate("DlgViewPrms", u"Back to :", None))
        self.label_30.setText(QCoreApplication.translate("DlgViewPrms", u"Save as default of :", None))
        self.btn_saveAsDefault_local.setText(QCoreApplication.translate("DlgViewPrms", u"Local", None))
    # retranslateUi

